/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_EQ_HPP_
#define _HEAVY_CONTEXT_WSTD_EQ_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvMath.h"
#include "HvControlSystem.h"
#include "HvControlBinop.h"
#include "HvSignalVar.h"
#include "HvControlVar.h"
#include "HvControlUnop.h"
#include "HvSignalLine.h"
#include "HvControlSlice.h"
#include "HvSignalBiquad.h"
#include "HvControlCast.h"
#include "HvControlIf.h"

class Heavy_WSTD_EQ : public HeavyContext {

 public:
  Heavy_WSTD_EQ(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_EQ();

  const char *getName() override { return "WSTD_EQ"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        HIGH = 0xC9CE7B11, // High
        LOW = 0x87744544, // Low
        MID = 0xBFDC48B6, // Mid
        MID_FREQ = 0x59CF21AC, // Mid_Freq
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_iv4AX7qc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_WU8vmRnZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_n45wO3vz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_taQaVfAa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_cD3aXHzw_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_foQ2W0FI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BOgL15rd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_CxmuKCzi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FifCE51N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Ge5xJzac_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_X9asvXTk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OGjWUe8X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YK5wLhG1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O1TQPjsA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vU2IlBwv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_clTh6PL9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KmChkOOj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DN0YMD14_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MCVro0OL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gaZNPWED_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_enQ6Loeg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vNE4XDbQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8RwZkchr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tHuM1GXl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gUZDz9vI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YzLmczbu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s459DX7O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9i4P5Ea3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QA6uEy0U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1VYbb7y3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_htA62vWS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_8WEI3JvX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_frS9Sv43_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_JMEhmIPB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hts9ivxA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vzW7Gux0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tB95aOz1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4WZzLPGG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OtNu2SVZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gkixuauq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FpKu5le5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GIi4wD0l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qbe2EoJz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_3hsMCbsn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2q0b4B60_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GuPiYA1h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KF1TtJ4a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dZnPdh3K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GafpE6kk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x3qtMkGV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CuSu6Mdx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RCFIPeWG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7Ixepinq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bPRrlIBF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_WzzHaa7x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Zvjf8h33_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_YC9LX51N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XHkbs3PO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UISS2USh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DjhtbHEd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UsDzcMQL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WFryMmhj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nnT21mqO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_k1efNF9d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qR97YtSk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BCLJvHp7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_An6e3Ey6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FvgQrz0K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_h8DBIciR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_laEGGzjp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0jK9XbPb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DBJHF2WU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1zf9NSHg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3CZGlloK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LShsrbM3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fZdznzat_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_T739TdeX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_X9HLxwtO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_5Ca47154_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_RYvRhy80_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZaR7pMZW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_jbUSd8Pp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_15AlJAsm_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_CbHDywF5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_20fD9Ygb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_WCENEj2O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_BpGisjIL_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_6J0jG9hq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5x8BCa1G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_GlhXOkJC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_eZhkfREV_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_Uo1EWTsH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_UvzccisB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_T2X0Gm0g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JsAuIOiH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JvMFECKH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_smT6lHJp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zV7qjYzm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IYfIUQvX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8KeEAQAf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_NHyYfTlB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_lItkcl4z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FxATIJKm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ViFdO1qw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Z1rk4QMo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fg1epnHm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XKYPHdiY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_0UWejf8w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_a8jSCmOK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FofYVaOd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0F8SANFj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aZqcxpU5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GuDTrERa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NHsxrqmq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Etr9ztc1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7KP4nH80_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oPcXFBRE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4YEDNchz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wyMfIoMM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_24pgS7Mw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_C5WAAX3u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oePHRlEP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tS7mm3Sl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pbyOzmCu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_sndpX6Yz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_uAE7C6Fr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mD2JVxHj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_trJvEsis_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_veGt0r2J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_EtNt8FRd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_m2Kpm2Jw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6EWVFkYv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZcMa2Wex_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_k4ReZjqn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0Iayf5Ot_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6pPEGBjO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_grqryv5D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tTkVrg58_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mKFxwIUB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QImocv3f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TiUsaE5I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WtVKkEKe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uA6BCvsE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cFjES9tw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QNNSif0U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xAQoe6bv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iiQRq7R3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TEvuR2Rs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rMDt1ums_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LdaTBBai_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_R6JcjVTB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7ZOnAFUf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Uia3D3wp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0yQncL9U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Y6Fi3MV9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g50oX0MO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tn7LlWZc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ViBQ4eus_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_xXVjFwsh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fRibboYg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fbf8f8Mo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Wo2lHIYE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LHOxfEFP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hoGZLwJT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_K3eFtBqr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_ONiuj33d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_I5Ub78a2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vQqLvMyw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1h2xOZBP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EzJSdJ7u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hddOQ4sW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3fKC2DVE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rvzbACU8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kIp8kRkK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EsIioy1L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_H4qCP6qD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VA6DWIcg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qGfiWmgp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pA42FjI8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vx5Ts6oT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_4ZPpz63d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_bCGnMlaX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_8PDHqALj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dR96SJCD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x782ROeC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L6tXZcur_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UrlgIWqA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mkQ4d6Fh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rRArDXWL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RMoRkUkk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_c18SR6lV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gSUN65Gt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DMEGv7Cb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LtQG7m4o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5NDPNukr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BjknLcWT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XfSKAw5h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8lXybQ3F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wul3NOQM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tBnU6tjL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_78oyU2EK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_t0kiN6UB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fP7Ilear_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_O0l9a98Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AJ5hCT99_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xl3AMcsQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wYoBTsvu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_JRvvHIUf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_lzGhQjpp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ibotljCX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VxGygozb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zysiR2sU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_btRz3NgB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dLtAwTY6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_t9jeNwyr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Vw4W44dF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z2NAN0J3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qmeo5LEw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mGhltVot_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_47l5QmBM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bnDTqSR3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4ruDzE5B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lq1cFXHO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7hHgMPui_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PrbBvHKq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LXNgk7Lo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bHHpv8of_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_buZx13s7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cp3ch0hy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4giZU9Lb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wPxd6kJm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ebWnAZzF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_oI40K8id_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bxGcZ5eG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_U1xSrIyV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iZajMxnr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DYSoDQ8N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_RMtEsEe2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_hwBhEMlC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_UrjaGvOC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_q3QWJHgT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cdtpHojx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0KY8jgmL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SVcJKGvB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Qa1dUJR6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ldcidYcs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qnISxSJr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_M5GnOFDt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_c3lZfRga_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Kt6c9XPB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fZfa1IJ4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UN5Lbtdd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GMg0qc30_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_K0amgQIr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_b1QG498F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NTIpRRR5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jIdVC6Sv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cmPCXhwp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bRzBaXCe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GRTaiZqZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_u0EKAGCS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qmo8nfBs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3bv6VFn3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UXY1qJiX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tnHUArsm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_NQIjN1Qn_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_LOr7DI0O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_olVBsYjG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_GSHOjuke_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3vZv4RXg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_WlSJt7Ok_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_4kGS3SvJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NVjeTrn2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PzCgHfN1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Lpb6Nt97_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eb4XsL7L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UUzUEEz9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vrybsTrk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_m9fOYZuq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vRx13sWz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_207eY8rA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_K6MVspJg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vW6wIHf7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6fBfdNcT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_G7FI0isn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Xapv3Pw3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OvO2YEhE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tMt4yrBi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QbgikhKU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_My0XpHE7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4soRQIno_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Rcb224zI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Yjf10teR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_rM34nlFH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_EUKN0ASx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VPLNjddt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SCBpgihF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fZQMsGOU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0fSo0gwW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2fyVEHWU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0rMEGDaW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2hucyxUf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QjIQEoek_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i0l3cYfY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_h5JocpeT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JBiTSApS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ALFJTcJ7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cxjQvnCh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5IkrntZ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QIQv37G3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tI7W5lEy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_m4cZyDrx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8QWtfsQh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yrPDHaln_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gPKxQgYC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_n4ojyqON_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ZNg2eCSO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ohIFxiX0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7yM0jYkr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UTr0sKsQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_saZPwiJa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VJqVoSOO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9EAVxXVR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LP8zPAec_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hYiwNjET_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_shwah1nx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IdO1UjVW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_VRdsZXIV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aeNR7jfV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lLHavm3v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hvtcfwW8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Q6HCFPGG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_owkZ8RKr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_W6IEKgsZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ci1X74um_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Vs9Orssc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KsZcsVuW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4dJqGDj5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_CKqHPvfS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_r2I7iVas_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_buVuCxZJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_pVpvRVYt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_7AeBVpCf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_vKJtvid4_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_P0npav1p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_C45RFSwe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ZOkarfg8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_omto0u4X_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_AfAQipbg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_a8vJajib_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_jpYOY6bK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_icxRvT7U_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_pCVIddNe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_iGz0WdY8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_UNDpmJIJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KPYo2o40_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IIgIY0hz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TxTl48t9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yHOZri9k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YjPhDkaD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jSlWhgog_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_KNQfQlI6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_ipJjhZIX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8PWjY56l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OV2bdx2R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BOB7kNVz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tBifUyNR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4oTXTYPV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Ud3vNXd0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_7GwOPRFy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Rh22khWu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5RjiFLDq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eSCK4rwX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Hj0u52fw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_K9IGaSjS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_dlpdhWeF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MRTocDBd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V4k7sQQQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DvFyCuLO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rxOqpSIF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cHF7E3ma_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1Dx4vSHv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hyHxDgF5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DjND9fPE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mmj3Ui9B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2lzLIP3v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_WuB0r1Mt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZaxZyiB2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_H7WezDjA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_vas2qKkD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_elNdpvUP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_byIV4DAq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bfw9K0Ch_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_D9ixAgIN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QIM5gfnR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_h52knXsQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YA4EgejO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cKERWFfY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_21q5XHtC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gzlB88GM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GHWNkNeD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Hby0q2sB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HrNhbkqc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yA6ahYGw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rOmxmg0R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jtamWOwK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LFxvOIXX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jiDTy1JK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uct9JqzZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6ZMdULNM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fthypEHW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lD3NU9jK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zRYahIc3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_va1UkjJo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LCjbkZlY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mlEC15vS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JvbDCZSL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_h7krDc4r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_QOxmLgX0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Xu9mLYQE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ytDD6NXm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FVyVJ81q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5IC6LSSO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SRtSqwLl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KhAEwudB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_9wetsXuM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_5ZW5b4xg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wEbPrUMO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xqbgl8rE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DwGVwgcO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ot0BTfmU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_y4vmAPbX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vNBNYJJ6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vekwnLFO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_81CWA5m8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ww60YMro_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xVbqMyZF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ninmu3NU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YS68iqXR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_t7yKTE22_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EbaWmpPr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Mu3q8cSl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_d69XwBLI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_XqmGBk5N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VIJsR0Yu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_46bKDRTF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4ySTZT8k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GGc0Xstv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aCfHDoya_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KmaUwtdL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iCRXdiEB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Rk1ZscFC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zUblXaac_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CdlY4iy9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LX5uPseo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_i0B0hxWf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cXAAoSTP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0A2ZHEZ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pMauJyPK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_apqXAgnc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RGhgygUF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_s564u2Zg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1AL7nvZH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OrRlWf3A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ItxSpo7k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FSSY3Yoj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1uiLN3em_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qOqFuOIB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_2qe6p8cS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_qaGIARkx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LjUvqG1L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s64zHejG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_f4t9ukl9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JP36DU8M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_svbL6fwW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_FzhO1QLE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_t0ewQshR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JQSoaq6h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ycp2otYP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Jri7N1oB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kE17gspi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LAli5tcU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4sAAHNop_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XTvf8HvO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FCp1AKfV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hVgle8tJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b78LIpTZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PKRUBNVN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Lc73anCZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qTtQeWOA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JtjRDv8q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fRYGDayY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_t398xvQe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bk2lVakQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_UGmlENyg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PFL04SSZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lT4Z1ic0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1bXnosy1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_c9DVCWBr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_zZL3apSV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_rj28TXSC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hxZCU5BX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1U8ILPzG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3NOK8RMa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xtyt6wWH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uY69o6pG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tmuswCLu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vxiQSwVE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jBctoR2q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5sCdzeZt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kKwVml8v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_G139okac_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TBbGuElg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OcIK99rX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_D5aEwixC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GxuafV6D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BltUp9qb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PaoJ5fbY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZCwQg9db_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9CgesaCt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oIuwxSr0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_x29UgsKk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xIzDKH8t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2hARdPHZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TnAnUcOL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_r7MHAw8E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_quPlospt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gyK8kFJS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_dbadTfuw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_h3upvB0i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1Qb6Pari_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ca6Zs0MX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jgTcddYF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pPSWJLm0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0rwVoS6S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pdQ5b87n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_TBBYuYEp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Wp5lYIjO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Fta4hiF1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_D70WcnSD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Xg0CJwwG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kXEu0NQy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UekhutNI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CtDoQzxl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fMGLJ56o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_La8zi46f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dB716uLK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ugDGTzbm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_v3MZaTXS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_cXNEaHwj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_2bFBofJt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_UnnJFRAt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_eCOWL2cF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_7SRaH4BO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_pEkYyncY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_k0s7Gj3M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6OIwRzw4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ExMN53im_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_saORuQgj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_WzqSYTei_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_tUQ1rc2b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_xL2N5fsn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_YwqTO3jA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_3qb4Kx2a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_2Hie5wTs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_cbpoVODA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_H2rjlE9G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_khiU34i9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_E5oEripj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Vy20iz7r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_2OPTDclH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_d2UvV6BS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_c4GZNigF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_zeVVvZjU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_SykvRUNN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_5prTbPmS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_clU5SGcK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ZMYum3sS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Tgnb9b1W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_QhEvDkji_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_zbn5mGLA_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_kZZ5h6If;
  SignalLine sLine_WhspttYG;
  SignalLine sLine_n3JASBrD;
  SignalLine sLine_d90Xsgzl;
  SignalLine sLine_wdJwMooU;
  SignalBiquad sBiquad_s_DZ9OPUA5;
  SignalLine sLine_loQXEiWM;
  SignalLine sLine_Qdqgn4ar;
  SignalLine sLine_kZM2G7JC;
  SignalLine sLine_5zwmhCfv;
  SignalBiquad sBiquad_s_RzLQim5G;
  SignalLine sLine_6LGvib9v;
  SignalLine sLine_zRLmUq2K;
  SignalLine sLine_WSbsCUON;
  SignalLine sLine_enhfAWwg;
  SignalLine sLine_el8lwS8B;
  SignalBiquad sBiquad_s_Nal4f1Fy;
  SignalLine sLine_c97ERpN2;
  SignalLine sLine_7DrQF2lV;
  SignalLine sLine_iReI7s7L;
  SignalLine sLine_bUVaFKUL;
  SignalLine sLine_1fm1vt77;
  SignalBiquad sBiquad_s_niZUSZ1t;
  SignalLine sLine_iymgOlvP;
  SignalLine sLine_XonqUsLJ;
  SignalLine sLine_4ymlGirf;
  SignalLine sLine_IpMCiPw6;
  SignalBiquad sBiquad_s_fymrXeR2;
  SignalLine sLine_WiZk9A0c;
  SignalLine sLine_czc3zBQG;
  SignalLine sLine_b3Z1VMFH;
  SignalLine sLine_zi8ojdYw;
  SignalLine sLine_TzQ3WEaf;
  SignalBiquad sBiquad_s_qQWlHVMB;
  ControlVar cVar_iv4AX7qc;
  ControlVar cVar_WU8vmRnZ;
  ControlVar cVar_n45wO3vz;
  ControlVar cVar_taQaVfAa;
  ControlSlice cSlice_foQ2W0FI;
  ControlVar cVar_BOgL15rd;
  ControlVar cVar_FifCE51N;
  ControlIf cIf_Ge5xJzac;
  ControlIf cIf_X9asvXTk;
  ControlBinop cBinop_YK5wLhG1;
  ControlBinop cBinop_O1TQPjsA;
  ControlBinop cBinop_KmChkOOj;
  ControlBinop cBinop_DN0YMD14;
  ControlBinop cBinop_gaZNPWED;
  ControlIf cIf_enQ6Loeg;
  ControlBinop cBinop_vNE4XDbQ;
  ControlBinop cBinop_8RwZkchr;
  ControlBinop cBinop_gUZDz9vI;
  ControlBinop cBinop_YzLmczbu;
  ControlBinop cBinop_s459DX7O;
  ControlVar cVar_8WEI3JvX;
  ControlIf cIf_frS9Sv43;
  ControlIf cIf_JMEhmIPB;
  ControlBinop cBinop_vzW7Gux0;
  ControlBinop cBinop_tB95aOz1;
  ControlBinop cBinop_gkixuauq;
  ControlBinop cBinop_FpKu5le5;
  ControlBinop cBinop_qbe2EoJz;
  ControlIf cIf_3hsMCbsn;
  ControlBinop cBinop_2q0b4B60;
  ControlBinop cBinop_GuPiYA1h;
  ControlBinop cBinop_dZnPdh3K;
  ControlBinop cBinop_GafpE6kk;
  ControlBinop cBinop_x3qtMkGV;
  ControlVar cVar_WzzHaa7x;
  ControlIf cIf_Zvjf8h33;
  ControlIf cIf_YC9LX51N;
  ControlBinop cBinop_UISS2USh;
  ControlBinop cBinop_DjhtbHEd;
  ControlBinop cBinop_nnT21mqO;
  ControlBinop cBinop_k1efNF9d;
  ControlBinop cBinop_BCLJvHp7;
  ControlIf cIf_An6e3Ey6;
  ControlBinop cBinop_FvgQrz0K;
  ControlBinop cBinop_h8DBIciR;
  ControlBinop cBinop_0jK9XbPb;
  ControlBinop cBinop_DBJHF2WU;
  ControlBinop cBinop_1zf9NSHg;
  ControlIf cIf_X9HLxwtO;
  ControlSlice cSlice_RYvRhy80;
  ControlVar cVar_ZaR7pMZW;
  ControlSlice cSlice_CbHDywF5;
  ControlVar cVar_20fD9Ygb;
  ControlSlice cSlice_6J0jG9hq;
  ControlVar cVar_5x8BCa1G;
  ControlSlice cSlice_Uo1EWTsH;
  ControlVar cVar_UvzccisB;
  ControlBinop cBinop_ViFdO1qw;
  ControlBinop cBinop_fg1epnHm;
  ControlBinop cBinop_XKYPHdiY;
  ControlBinop cBinop_FofYVaOd;
  ControlBinop cBinop_0F8SANFj;
  ControlBinop cBinop_aZqcxpU5;
  ControlBinop cBinop_GuDTrERa;
  ControlBinop cBinop_NHsxrqmq;
  ControlVar cVar_Etr9ztc1;
  ControlBinop cBinop_7KP4nH80;
  ControlBinop cBinop_oPcXFBRE;
  ControlBinop cBinop_4YEDNchz;
  ControlBinop cBinop_wyMfIoMM;
  ControlBinop cBinop_24pgS7Mw;
  ControlBinop cBinop_C5WAAX3u;
  ControlBinop cBinop_oePHRlEP;
  ControlBinop cBinop_pbyOzmCu;
  ControlVar cVar_sndpX6Yz;
  ControlVar cVar_uAE7C6Fr;
  ControlBinop cBinop_ZcMa2Wex;
  ControlBinop cBinop_k4ReZjqn;
  ControlBinop cBinop_0Iayf5Ot;
  ControlBinop cBinop_grqryv5D;
  ControlBinop cBinop_tTkVrg58;
  ControlBinop cBinop_mKFxwIUB;
  ControlBinop cBinop_QImocv3f;
  ControlBinop cBinop_TiUsaE5I;
  ControlBinop cBinop_WtVKkEKe;
  ControlBinop cBinop_fbf8f8Mo;
  ControlBinop cBinop_LHOxfEFP;
  ControlBinop cBinop_hoGZLwJT;
  ControlBinop cBinop_I5Ub78a2;
  ControlBinop cBinop_vQqLvMyw;
  ControlBinop cBinop_1h2xOZBP;
  ControlBinop cBinop_EzJSdJ7u;
  ControlBinop cBinop_hddOQ4sW;
  ControlBinop cBinop_3fKC2DVE;
  ControlBinop cBinop_rvzbACU8;
  ControlBinop cBinop_EsIioy1L;
  ControlVar cVar_H4qCP6qD;
  ControlVar cVar_VA6DWIcg;
  ControlVar cVar_qGfiWmgp;
  ControlBinop cBinop_x782ROeC;
  ControlBinop cBinop_L6tXZcur;
  ControlBinop cBinop_UrlgIWqA;
  ControlBinop cBinop_rRArDXWL;
  ControlBinop cBinop_RMoRkUkk;
  ControlBinop cBinop_c18SR6lV;
  ControlBinop cBinop_gSUN65Gt;
  ControlBinop cBinop_DMEGv7Cb;
  ControlBinop cBinop_VxGygozb;
  ControlBinop cBinop_btRz3NgB;
  ControlBinop cBinop_dLtAwTY6;
  ControlBinop cBinop_Z2NAN0J3;
  ControlBinop cBinop_qmeo5LEw;
  ControlBinop cBinop_mGhltVot;
  ControlBinop cBinop_47l5QmBM;
  ControlBinop cBinop_bnDTqSR3;
  ControlBinop cBinop_lq1cFXHO;
  ControlBinop cBinop_PrbBvHKq;
  ControlBinop cBinop_LXNgk7Lo;
  ControlBinop cBinop_buZx13s7;
  ControlBinop cBinop_cp3ch0hy;
  ControlBinop cBinop_4giZU9Lb;
  ControlBinop cBinop_ebWnAZzF;
  ControlVar cVar_oI40K8id;
  ControlVar cVar_bxGcZ5eG;
  ControlVar cVar_U1xSrIyV;
  ControlBinop cBinop_cdtpHojx;
  ControlBinop cBinop_0KY8jgmL;
  ControlBinop cBinop_SVcJKGvB;
  ControlBinop cBinop_ldcidYcs;
  ControlBinop cBinop_qnISxSJr;
  ControlBinop cBinop_M5GnOFDt;
  ControlBinop cBinop_c3lZfRga;
  ControlBinop cBinop_Kt6c9XPB;
  ControlBinop cBinop_fZfa1IJ4;
  ControlBinop cBinop_qmo8nfBs;
  ControlBinop cBinop_UXY1qJiX;
  ControlBinop cBinop_tnHUArsm;
  SignalVarf sVarf_1a2jUahA;
  SignalVarf sVarf_tCvV2yKI;
  SignalVarf sVarf_HnMuUfpx;
  ControlSlice cSlice_LOr7DI0O;
  ControlVar cVar_olVBsYjG;
  ControlVar cVar_3vZv4RXg;
  ControlIf cIf_WlSJt7Ok;
  ControlIf cIf_4kGS3SvJ;
  ControlBinop cBinop_PzCgHfN1;
  ControlBinop cBinop_Lpb6Nt97;
  ControlBinop cBinop_vrybsTrk;
  ControlBinop cBinop_m9fOYZuq;
  ControlBinop cBinop_207eY8rA;
  ControlIf cIf_K6MVspJg;
  ControlBinop cBinop_vW6wIHf7;
  ControlBinop cBinop_6fBfdNcT;
  ControlBinop cBinop_Xapv3Pw3;
  ControlBinop cBinop_OvO2YEhE;
  ControlBinop cBinop_tMt4yrBi;
  ControlVar cVar_Yjf10teR;
  ControlIf cIf_rM34nlFH;
  ControlIf cIf_EUKN0ASx;
  ControlBinop cBinop_SCBpgihF;
  ControlBinop cBinop_fZQMsGOU;
  ControlBinop cBinop_0rMEGDaW;
  ControlBinop cBinop_2hucyxUf;
  ControlBinop cBinop_i0l3cYfY;
  ControlIf cIf_h5JocpeT;
  ControlBinop cBinop_JBiTSApS;
  ControlBinop cBinop_ALFJTcJ7;
  ControlBinop cBinop_5IkrntZ0;
  ControlBinop cBinop_QIQv37G3;
  ControlBinop cBinop_tI7W5lEy;
  ControlVar cVar_n4ojyqON;
  ControlIf cIf_ZNg2eCSO;
  ControlIf cIf_ohIFxiX0;
  ControlBinop cBinop_UTr0sKsQ;
  ControlBinop cBinop_saZPwiJa;
  ControlBinop cBinop_LP8zPAec;
  ControlBinop cBinop_hYiwNjET;
  ControlBinop cBinop_IdO1UjVW;
  ControlIf cIf_VRdsZXIV;
  ControlBinop cBinop_aeNR7jfV;
  ControlBinop cBinop_lLHavm3v;
  ControlBinop cBinop_Q6HCFPGG;
  ControlBinop cBinop_owkZ8RKr;
  ControlBinop cBinop_W6IEKgsZ;
  ControlIf cIf_CKqHPvfS;
  ControlSlice cSlice_buVuCxZJ;
  ControlVar cVar_pVpvRVYt;
  ControlSlice cSlice_P0npav1p;
  ControlVar cVar_C45RFSwe;
  ControlSlice cSlice_AfAQipbg;
  ControlVar cVar_a8vJajib;
  ControlSlice cSlice_pCVIddNe;
  ControlVar cVar_iGz0WdY8;
  ControlBinop cBinop_OV2bdx2R;
  ControlBinop cBinop_tBifUyNR;
  ControlBinop cBinop_4oTXTYPV;
  ControlBinop cBinop_Rh22khWu;
  ControlBinop cBinop_5RjiFLDq;
  ControlBinop cBinop_eSCK4rwX;
  ControlBinop cBinop_Hj0u52fw;
  ControlBinop cBinop_K9IGaSjS;
  ControlVar cVar_dlpdhWeF;
  ControlBinop cBinop_MRTocDBd;
  ControlBinop cBinop_V4k7sQQQ;
  ControlBinop cBinop_DvFyCuLO;
  ControlBinop cBinop_rxOqpSIF;
  ControlBinop cBinop_cHF7E3ma;
  ControlBinop cBinop_1Dx4vSHv;
  ControlBinop cBinop_hyHxDgF5;
  ControlBinop cBinop_mmj3Ui9B;
  ControlVar cVar_2lzLIP3v;
  ControlVar cVar_WuB0r1Mt;
  ControlBinop cBinop_D9ixAgIN;
  ControlBinop cBinop_QIM5gfnR;
  ControlBinop cBinop_h52knXsQ;
  ControlBinop cBinop_cKERWFfY;
  ControlBinop cBinop_21q5XHtC;
  ControlBinop cBinop_gzlB88GM;
  ControlBinop cBinop_GHWNkNeD;
  ControlBinop cBinop_Hby0q2sB;
  ControlBinop cBinop_HrNhbkqc;
  ControlBinop cBinop_FVyVJ81q;
  ControlBinop cBinop_SRtSqwLl;
  ControlBinop cBinop_KhAEwudB;
  ControlBinop cBinop_wEbPrUMO;
  ControlBinop cBinop_xqbgl8rE;
  ControlBinop cBinop_DwGVwgcO;
  ControlBinop cBinop_Ot0BTfmU;
  ControlBinop cBinop_y4vmAPbX;
  ControlBinop cBinop_vNBNYJJ6;
  ControlBinop cBinop_vekwnLFO;
  ControlBinop cBinop_Ww60YMro;
  ControlVar cVar_xVbqMyZF;
  ControlVar cVar_ninmu3NU;
  ControlVar cVar_YS68iqXR;
  ControlBinop cBinop_46bKDRTF;
  ControlBinop cBinop_4ySTZT8k;
  ControlBinop cBinop_GGc0Xstv;
  ControlBinop cBinop_KmaUwtdL;
  ControlBinop cBinop_iCRXdiEB;
  ControlBinop cBinop_Rk1ZscFC;
  ControlBinop cBinop_zUblXaac;
  ControlBinop cBinop_CdlY4iy9;
  ControlBinop cBinop_s64zHejG;
  ControlBinop cBinop_JP36DU8M;
  ControlBinop cBinop_svbL6fwW;
  ControlBinop cBinop_JQSoaq6h;
  ControlBinop cBinop_Ycp2otYP;
  ControlBinop cBinop_Jri7N1oB;
  ControlBinop cBinop_kE17gspi;
  ControlBinop cBinop_LAli5tcU;
  ControlBinop cBinop_XTvf8HvO;
  ControlBinop cBinop_hVgle8tJ;
  ControlBinop cBinop_b78LIpTZ;
  ControlBinop cBinop_Lc73anCZ;
  ControlBinop cBinop_qTtQeWOA;
  ControlBinop cBinop_JtjRDv8q;
  ControlBinop cBinop_t398xvQe;
  ControlVar cVar_bk2lVakQ;
  ControlVar cVar_UGmlENyg;
  ControlVar cVar_PFL04SSZ;
  ControlBinop cBinop_1U8ILPzG;
  ControlBinop cBinop_3NOK8RMa;
  ControlBinop cBinop_xtyt6wWH;
  ControlBinop cBinop_tmuswCLu;
  ControlBinop cBinop_vxiQSwVE;
  ControlBinop cBinop_jBctoR2q;
  ControlBinop cBinop_5sCdzeZt;
  ControlBinop cBinop_kKwVml8v;
  ControlBinop cBinop_G139okac;
  ControlBinop cBinop_xIzDKH8t;
  ControlBinop cBinop_TnAnUcOL;
  ControlBinop cBinop_r7MHAw8E;
  SignalVarf sVarf_cZt0SmLv;
  SignalVarf sVarf_Sxoc2svG;
  SignalVarf sVarf_oUQAyoNz;
  SignalVarf sVarf_3WJBcLGs;
  SignalVarf sVarf_QsjKsq2r;
  SignalVarf sVarf_aqVQWq1E;
  SignalVarf sVarf_CiFi0U0D;
  SignalVarf sVarf_9pYvl3dk;
  SignalVarf sVarf_qZ8h6tW9;
  ControlVar cVar_quPlospt;
  ControlVar cVar_gyK8kFJS;
  ControlBinop cBinop_pPSWJLm0;
  ControlBinop cBinop_0rwVoS6S;
  ControlBinop cBinop_pdQ5b87n;
  ControlBinop cBinop_Wp5lYIjO;
  ControlBinop cBinop_Fta4hiF1;
  ControlBinop cBinop_D70WcnSD;
  ControlBinop cBinop_Xg0CJwwG;
};

#endif // _HEAVY_CONTEXT_WSTD_EQ_HPP_
