/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_EQ.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_EQ *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_EQ_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_EQ));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_EQ(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_EQ_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_EQ));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_EQ(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_EQ_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_EQ();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_EQ::Heavy_WSTD_EQ(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_kZZ5h6If);
  numBytes += sLine_init(&sLine_WhspttYG);
  numBytes += sLine_init(&sLine_n3JASBrD);
  numBytes += sLine_init(&sLine_d90Xsgzl);
  numBytes += sLine_init(&sLine_wdJwMooU);
  numBytes += sBiquad_init(&sBiquad_s_DZ9OPUA5);
  numBytes += sLine_init(&sLine_loQXEiWM);
  numBytes += sLine_init(&sLine_Qdqgn4ar);
  numBytes += sLine_init(&sLine_kZM2G7JC);
  numBytes += sLine_init(&sLine_5zwmhCfv);
  numBytes += sBiquad_init(&sBiquad_s_RzLQim5G);
  numBytes += sLine_init(&sLine_6LGvib9v);
  numBytes += sLine_init(&sLine_zRLmUq2K);
  numBytes += sLine_init(&sLine_WSbsCUON);
  numBytes += sLine_init(&sLine_enhfAWwg);
  numBytes += sLine_init(&sLine_el8lwS8B);
  numBytes += sBiquad_init(&sBiquad_s_Nal4f1Fy);
  numBytes += sLine_init(&sLine_c97ERpN2);
  numBytes += sLine_init(&sLine_7DrQF2lV);
  numBytes += sLine_init(&sLine_iReI7s7L);
  numBytes += sLine_init(&sLine_bUVaFKUL);
  numBytes += sLine_init(&sLine_1fm1vt77);
  numBytes += sBiquad_init(&sBiquad_s_niZUSZ1t);
  numBytes += sLine_init(&sLine_iymgOlvP);
  numBytes += sLine_init(&sLine_XonqUsLJ);
  numBytes += sLine_init(&sLine_4ymlGirf);
  numBytes += sLine_init(&sLine_IpMCiPw6);
  numBytes += sBiquad_init(&sBiquad_s_fymrXeR2);
  numBytes += sLine_init(&sLine_WiZk9A0c);
  numBytes += sLine_init(&sLine_czc3zBQG);
  numBytes += sLine_init(&sLine_b3Z1VMFH);
  numBytes += sLine_init(&sLine_zi8ojdYw);
  numBytes += sLine_init(&sLine_TzQ3WEaf);
  numBytes += sBiquad_init(&sBiquad_s_qQWlHVMB);
  numBytes += cVar_init_f(&cVar_iv4AX7qc, 0.0f);
  numBytes += cVar_init_f(&cVar_WU8vmRnZ, 0.0f);
  numBytes += cVar_init_f(&cVar_n45wO3vz, 0.0f);
  numBytes += cVar_init_f(&cVar_taQaVfAa, 0.0f);
  numBytes += cSlice_init(&cSlice_foQ2W0FI, 1, -1);
  numBytes += cVar_init_f(&cVar_BOgL15rd, 1337.0f);
  numBytes += cVar_init_f(&cVar_FifCE51N, 0.0f);
  numBytes += cIf_init(&cIf_Ge5xJzac, false);
  numBytes += cIf_init(&cIf_X9asvXTk, false);
  numBytes += cBinop_init(&cBinop_YK5wLhG1, 0.0f); // __pow
  numBytes += cIf_init(&cIf_enQ6Loeg, false);
  numBytes += cBinop_init(&cBinop_gUZDz9vI, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_YzLmczbu, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_s459DX7O, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_8WEI3JvX, 0.0f);
  numBytes += cIf_init(&cIf_frS9Sv43, false);
  numBytes += cIf_init(&cIf_JMEhmIPB, false);
  numBytes += cBinop_init(&cBinop_vzW7Gux0, 0.0f); // __pow
  numBytes += cIf_init(&cIf_3hsMCbsn, false);
  numBytes += cBinop_init(&cBinop_dZnPdh3K, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_GafpE6kk, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_x3qtMkGV, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_WzzHaa7x, 0.0f);
  numBytes += cIf_init(&cIf_Zvjf8h33, false);
  numBytes += cIf_init(&cIf_YC9LX51N, false);
  numBytes += cBinop_init(&cBinop_UISS2USh, 0.0f); // __pow
  numBytes += cIf_init(&cIf_An6e3Ey6, false);
  numBytes += cBinop_init(&cBinop_0jK9XbPb, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_DBJHF2WU, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_1zf9NSHg, -15.0f); // __eq
  numBytes += cIf_init(&cIf_X9HLxwtO, false);
  numBytes += cSlice_init(&cSlice_RYvRhy80, 1, -1);
  numBytes += cVar_init_f(&cVar_ZaR7pMZW, 0.0f);
  numBytes += cSlice_init(&cSlice_CbHDywF5, 1, -1);
  numBytes += cVar_init_f(&cVar_20fD9Ygb, 0.0f);
  numBytes += cSlice_init(&cSlice_6J0jG9hq, 1, -1);
  numBytes += cVar_init_f(&cVar_5x8BCa1G, 0.0f);
  numBytes += cSlice_init(&cSlice_Uo1EWTsH, 1, -1);
  numBytes += cVar_init_f(&cVar_UvzccisB, 0.313f);
  numBytes += cBinop_init(&cBinop_fg1epnHm, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_XKYPHdiY, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_Etr9ztc1, 0.0f);
  numBytes += cVar_init_f(&cVar_sndpX6Yz, 1337.0f);
  numBytes += cVar_init_f(&cVar_uAE7C6Fr, 0.3f);
  numBytes += cBinop_init(&cBinop_k4ReZjqn, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_tTkVrg58, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_mKFxwIUB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_QImocv3f, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_TiUsaE5I, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_WtVKkEKe, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_LHOxfEFP, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_hoGZLwJT, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_H4qCP6qD, 0.0f);
  numBytes += cVar_init_f(&cVar_VA6DWIcg, 1337.0f);
  numBytes += cVar_init_f(&cVar_qGfiWmgp, 0.313f);
  numBytes += cBinop_init(&cBinop_L6tXZcur, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_RMoRkUkk, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_c18SR6lV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gSUN65Gt, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DMEGv7Cb, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_btRz3NgB, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_dLtAwTY6, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_oI40K8id, 0.0f);
  numBytes += cVar_init_f(&cVar_bxGcZ5eG, 1037.0f);
  numBytes += cVar_init_f(&cVar_U1xSrIyV, 0.4f);
  numBytes += cBinop_init(&cBinop_0KY8jgmL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qnISxSJr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_M5GnOFDt, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_c3lZfRga, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Kt6c9XPB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_fZfa1IJ4, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_1a2jUahA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_tCvV2yKI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HnMuUfpx, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_LOr7DI0O, 1, -1);
  numBytes += cVar_init_f(&cVar_olVBsYjG, 1337.0f);
  numBytes += cVar_init_f(&cVar_3vZv4RXg, 0.0f);
  numBytes += cIf_init(&cIf_WlSJt7Ok, false);
  numBytes += cIf_init(&cIf_4kGS3SvJ, false);
  numBytes += cBinop_init(&cBinop_PzCgHfN1, 0.0f); // __pow
  numBytes += cIf_init(&cIf_K6MVspJg, false);
  numBytes += cBinop_init(&cBinop_Xapv3Pw3, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_OvO2YEhE, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_tMt4yrBi, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_Yjf10teR, 0.0f);
  numBytes += cIf_init(&cIf_rM34nlFH, false);
  numBytes += cIf_init(&cIf_EUKN0ASx, false);
  numBytes += cBinop_init(&cBinop_SCBpgihF, 0.0f); // __pow
  numBytes += cIf_init(&cIf_h5JocpeT, false);
  numBytes += cBinop_init(&cBinop_5IkrntZ0, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_QIQv37G3, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_tI7W5lEy, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_n4ojyqON, 0.0f);
  numBytes += cIf_init(&cIf_ZNg2eCSO, false);
  numBytes += cIf_init(&cIf_ohIFxiX0, false);
  numBytes += cBinop_init(&cBinop_UTr0sKsQ, 0.0f); // __pow
  numBytes += cIf_init(&cIf_VRdsZXIV, false);
  numBytes += cBinop_init(&cBinop_Q6HCFPGG, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_owkZ8RKr, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_W6IEKgsZ, -15.0f); // __eq
  numBytes += cIf_init(&cIf_CKqHPvfS, false);
  numBytes += cSlice_init(&cSlice_buVuCxZJ, 1, -1);
  numBytes += cVar_init_f(&cVar_pVpvRVYt, 0.0f);
  numBytes += cSlice_init(&cSlice_P0npav1p, 1, -1);
  numBytes += cVar_init_f(&cVar_C45RFSwe, 0.0f);
  numBytes += cSlice_init(&cSlice_AfAQipbg, 1, -1);
  numBytes += cVar_init_f(&cVar_a8vJajib, 0.0f);
  numBytes += cSlice_init(&cSlice_pCVIddNe, 1, -1);
  numBytes += cVar_init_f(&cVar_iGz0WdY8, 0.313f);
  numBytes += cBinop_init(&cBinop_tBifUyNR, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_4oTXTYPV, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_dlpdhWeF, 0.0f);
  numBytes += cVar_init_f(&cVar_2lzLIP3v, 1337.0f);
  numBytes += cVar_init_f(&cVar_WuB0r1Mt, 0.3f);
  numBytes += cBinop_init(&cBinop_QIM5gfnR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_21q5XHtC, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gzlB88GM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_GHWNkNeD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Hby0q2sB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_HrNhbkqc, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_SRtSqwLl, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_KhAEwudB, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_xVbqMyZF, 0.0f);
  numBytes += cVar_init_f(&cVar_ninmu3NU, 1337.0f);
  numBytes += cVar_init_f(&cVar_YS68iqXR, 0.313f);
  numBytes += cBinop_init(&cBinop_4ySTZT8k, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_iCRXdiEB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Rk1ZscFC, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zUblXaac, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_CdlY4iy9, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_JP36DU8M, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_svbL6fwW, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_bk2lVakQ, 0.0f);
  numBytes += cVar_init_f(&cVar_UGmlENyg, 1037.0f);
  numBytes += cVar_init_f(&cVar_PFL04SSZ, 0.4f);
  numBytes += cBinop_init(&cBinop_3NOK8RMa, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vxiQSwVE, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jBctoR2q, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_5sCdzeZt, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_kKwVml8v, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_G139okac, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_cZt0SmLv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Sxoc2svG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oUQAyoNz, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3WJBcLGs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QsjKsq2r, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_aqVQWq1E, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CiFi0U0D, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9pYvl3dk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qZ8h6tW9, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_quPlospt, 5705.6f);
  numBytes += cVar_init_f(&cVar_gyK8kFJS, 313.3f);
  numBytes += cBinop_init(&cBinop_pPSWJLm0, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_0rwVoS6S, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_pdQ5b87n, 0.0f); // __div
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_EQ::~Heavy_WSTD_EQ() {
  // nothing to free
}

HvTable *Heavy_WSTD_EQ::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_EQ::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_v3MZaTXS_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2bFBofJt_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cXNEaHwj_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zbn5mGLA_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7SRaH4BO_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pEkYyncY_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UnnJFRAt_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eCOWL2cF_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_k0s7Gj3M_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WzqSYTei_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_saORuQgj_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ExMN53im_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YwqTO3jA_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xL2N5fsn_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tUQ1rc2b_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cbpoVODA_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2Hie5wTs_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3qb4Kx2a_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_E5oEripj_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Vy20iz7r_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_H2rjlE9G_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_khiU34i9_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2OPTDclH_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zeVVvZjU_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_c4GZNigF_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_d2UvV6BS_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_clU5SGcK_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5prTbPmS_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SykvRUNN_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QhEvDkji_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Tgnb9b1W_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZMYum3sS_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6OIwRzw4_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_EQ::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_EQ::cVar_iv4AX7qc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kXEu0NQy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_WU8vmRnZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UekhutNI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_n45wO3vz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CtDoQzxl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_taQaVfAa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fMGLJ56o_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jgTcddYF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ca6Zs0MX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1Qb6Pari_sendMessage);
}

void Heavy_WSTD_EQ::cSwitchcase_cD3aXHzw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_foQ2W0FI, 0, m, &cSlice_foQ2W0FI_sendMessage);
      break;
    }
    default: {
      cSwitchcase_BpGisjIL_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_foQ2W0FI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_CxmuKCzi_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_CxmuKCzi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_BOgL15rd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CxmuKCzi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_CxmuKCzi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UnnJFRAt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_FifCE51N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_vNE4XDbQ_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Ge5xJzac, 0, m, &cIf_Ge5xJzac_sendMessage);
}

void Heavy_WSTD_EQ::cIf_Ge5xJzac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_8RwZkchr_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_X9asvXTk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_MCVro0OL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_DN0YMD14_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_OGjWUe8X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_YK5wLhG1, HV_BINOP_POW, 0, m, &cBinop_YK5wLhG1_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_YK5wLhG1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_enQ6Loeg, 0, m, &cIf_enQ6Loeg_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_O1TQPjsA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_gaZNPWED_sendMessage);
}

void Heavy_WSTD_EQ::cCast_vU2IlBwv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_X9asvXTk, 0, m, &cIf_X9asvXTk_sendMessage);
}

void Heavy_WSTD_EQ::cCast_clTh6PL9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_KmChkOOj_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_KmChkOOj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_X9asvXTk, 1, m, &cIf_X9asvXTk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_DN0YMD14_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_O1TQPjsA_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_MCVro0OL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_enQ6Loeg, 0, m, &cIf_enQ6Loeg_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_gaZNPWED_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YK5wLhG1, HV_BINOP_POW, 1, m, &cBinop_YK5wLhG1_sendMessage);
  cMsg_OGjWUe8X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_enQ6Loeg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_1a2jUahA, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_vNE4XDbQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ge5xJzac, 1, m, &cIf_Ge5xJzac_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_8RwZkchr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YzLmczbu, HV_BINOP_GREATER_THAN, 1, m, &cBinop_YzLmczbu_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_s459DX7O, HV_BINOP_EQ, 1, m, &cBinop_s459DX7O_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_tHuM1GXl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_gUZDz9vI, HV_BINOP_ADD, 0, m, &cBinop_gUZDz9vI_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_gUZDz9vI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_clTh6PL9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vU2IlBwv_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_YzLmczbu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_enQ6Loeg, 1, m, &cIf_enQ6Loeg_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_s459DX7O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9i4P5Ea3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_9i4P5Ea3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_1a2jUahA, m);
}

void Heavy_WSTD_EQ::cCast_QA6uEy0U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gUZDz9vI, HV_BINOP_ADD, 1, m, &cBinop_gUZDz9vI_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_YzLmczbu, HV_BINOP_GREATER_THAN, 0, m, &cBinop_YzLmczbu_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_s459DX7O, HV_BINOP_EQ, 0, m, &cBinop_s459DX7O_sendMessage);
}

void Heavy_WSTD_EQ::cCast_1VYbb7y3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FifCE51N, 0, m, &cVar_FifCE51N_sendMessage);
}

void Heavy_WSTD_EQ::cCast_htA62vWS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tHuM1GXl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_8WEI3JvX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_2q0b4B60_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_frS9Sv43, 0, m, &cIf_frS9Sv43_sendMessage);
}

void Heavy_WSTD_EQ::cIf_frS9Sv43_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_GuPiYA1h_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_JMEhmIPB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_GIi4wD0l_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_FpKu5le5_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_hts9ivxA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_vzW7Gux0, HV_BINOP_POW, 0, m, &cBinop_vzW7Gux0_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_vzW7Gux0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3hsMCbsn, 0, m, &cIf_3hsMCbsn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tB95aOz1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_qbe2EoJz_sendMessage);
}

void Heavy_WSTD_EQ::cCast_4WZzLPGG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JMEhmIPB, 0, m, &cIf_JMEhmIPB_sendMessage);
}

void Heavy_WSTD_EQ::cCast_OtNu2SVZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_gkixuauq_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_gkixuauq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JMEhmIPB, 1, m, &cIf_JMEhmIPB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_FpKu5le5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_tB95aOz1_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_GIi4wD0l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_3hsMCbsn, 0, m, &cIf_3hsMCbsn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qbe2EoJz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vzW7Gux0, HV_BINOP_POW, 1, m, &cBinop_vzW7Gux0_sendMessage);
  cMsg_hts9ivxA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_3hsMCbsn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_qmo8nfBs_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_UXY1qJiX_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_tnHUArsm_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_2q0b4B60_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_frS9Sv43, 1, m, &cIf_frS9Sv43_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GuPiYA1h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GafpE6kk, HV_BINOP_GREATER_THAN, 1, m, &cBinop_GafpE6kk_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_x3qtMkGV, HV_BINOP_EQ, 1, m, &cBinop_x3qtMkGV_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_KF1TtJ4a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_dZnPdh3K, HV_BINOP_ADD, 0, m, &cBinop_dZnPdh3K_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_dZnPdh3K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OtNu2SVZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4WZzLPGG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GafpE6kk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3hsMCbsn, 1, m, &cIf_3hsMCbsn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_x3qtMkGV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CuSu6Mdx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_CuSu6Mdx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_qmo8nfBs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_UXY1qJiX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_tnHUArsm_sendMessage);
}

void Heavy_WSTD_EQ::cCast_RCFIPeWG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dZnPdh3K, HV_BINOP_ADD, 1, m, &cBinop_dZnPdh3K_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_GafpE6kk, HV_BINOP_GREATER_THAN, 0, m, &cBinop_GafpE6kk_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_x3qtMkGV, HV_BINOP_EQ, 0, m, &cBinop_x3qtMkGV_sendMessage);
}

void Heavy_WSTD_EQ::cCast_7Ixepinq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8WEI3JvX, 0, m, &cVar_8WEI3JvX_sendMessage);
}

void Heavy_WSTD_EQ::cCast_bPRrlIBF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KF1TtJ4a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_WzzHaa7x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_FvgQrz0K_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Zvjf8h33, 0, m, &cIf_Zvjf8h33_sendMessage);
}

void Heavy_WSTD_EQ::cIf_Zvjf8h33_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_h8DBIciR_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_YC9LX51N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_qR97YtSk_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_k1efNF9d_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_XHkbs3PO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UISS2USh, HV_BINOP_POW, 0, m, &cBinop_UISS2USh_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_UISS2USh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_An6e3Ey6, 0, m, &cIf_An6e3Ey6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_DjhtbHEd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_BCLJvHp7_sendMessage);
}

void Heavy_WSTD_EQ::cCast_UsDzcMQL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YC9LX51N, 0, m, &cIf_YC9LX51N_sendMessage);
}

void Heavy_WSTD_EQ::cCast_WFryMmhj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_nnT21mqO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_nnT21mqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YC9LX51N, 1, m, &cIf_YC9LX51N_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_k1efNF9d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_DjhtbHEd_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_qR97YtSk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_An6e3Ey6, 0, m, &cIf_An6e3Ey6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_BCLJvHp7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UISS2USh, HV_BINOP_POW, 1, m, &cBinop_UISS2USh_sendMessage);
  cMsg_XHkbs3PO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_An6e3Ey6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_HnMuUfpx, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_FvgQrz0K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Zvjf8h33, 1, m, &cIf_Zvjf8h33_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_h8DBIciR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DBJHF2WU, HV_BINOP_GREATER_THAN, 1, m, &cBinop_DBJHF2WU_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1zf9NSHg, HV_BINOP_EQ, 1, m, &cBinop_1zf9NSHg_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_laEGGzjp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_0jK9XbPb, HV_BINOP_ADD, 0, m, &cBinop_0jK9XbPb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0jK9XbPb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WFryMmhj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UsDzcMQL_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_DBJHF2WU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_An6e3Ey6, 1, m, &cIf_An6e3Ey6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_1zf9NSHg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3CZGlloK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_3CZGlloK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_HnMuUfpx, m);
}

void Heavy_WSTD_EQ::cCast_LShsrbM3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0jK9XbPb, HV_BINOP_ADD, 1, m, &cBinop_0jK9XbPb_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DBJHF2WU, HV_BINOP_GREATER_THAN, 0, m, &cBinop_DBJHF2WU_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1zf9NSHg, HV_BINOP_EQ, 0, m, &cBinop_1zf9NSHg_sendMessage);
}

void Heavy_WSTD_EQ::cCast_fZdznzat_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WzzHaa7x, 0, m, &cVar_WzzHaa7x_sendMessage);
}

void Heavy_WSTD_EQ::cCast_T739TdeX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_laEGGzjp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_X9HLxwtO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_tCvV2yKI, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cSwitchcase_5Ca47154_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_RYvRhy80, 0, m, &cSlice_RYvRhy80_sendMessage);
      break;
    }
    default: {
      cSwitchcase_15AlJAsm_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_RYvRhy80_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_jbUSd8Pp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_jbUSd8Pp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_ZaR7pMZW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jbUSd8Pp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_jbUSd8Pp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7SRaH4BO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_15AlJAsm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_CbHDywF5, 0, m, &cSlice_CbHDywF5_sendMessage);
      break;
    }
    default: {
      cSwitchcase_cD3aXHzw_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_CbHDywF5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_WCENEj2O_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_WCENEj2O_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_20fD9Ygb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WCENEj2O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_WCENEj2O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_k0s7Gj3M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_BpGisjIL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_6J0jG9hq, 0, m, &cSlice_6J0jG9hq_sendMessage);
      break;
    }
    default: {
      cSwitchcase_eZhkfREV_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_6J0jG9hq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_GlhXOkJC_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_GlhXOkJC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_5x8BCa1G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GlhXOkJC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_GlhXOkJC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pEkYyncY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_eZhkfREV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Uo1EWTsH, 0, m, &cSlice_Uo1EWTsH_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_Uo1EWTsH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_T2X0Gm0g_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_T2X0Gm0g_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_UvzccisB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_T2X0Gm0g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_T2X0Gm0g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_eCOWL2cF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_JsAuIOiH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kZZ5h6If, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_JvMFECKH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WhspttYG, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_smT6lHJp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_n3JASBrD, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_zV7qjYzm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_d90Xsgzl, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_IYfIUQvX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wdJwMooU, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_8KeEAQAf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_NHyYfTlB_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_NHyYfTlB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fg1epnHm, HV_BINOP_DIVIDE, 1, m, &cBinop_fg1epnHm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Z1rk4QMo_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_lItkcl4z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_ViFdO1qw_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_FxATIJKm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_lItkcl4z_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ViFdO1qw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fg1epnHm, HV_BINOP_DIVIDE, 0, m, &cBinop_fg1epnHm_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Z1rk4QMo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FxATIJKm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_fg1epnHm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XKYPHdiY, HV_BINOP_MULTIPLY, 1, m, &cBinop_XKYPHdiY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_XKYPHdiY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_trJvEsis_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mD2JVxHj_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_0UWejf8w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_veGt0r2J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_a8jSCmOK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EtNt8FRd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_FofYVaOd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_0F8SANFj_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0F8SANFj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XKYPHdiY, HV_BINOP_MULTIPLY, 0, m, &cBinop_XKYPHdiY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_aZqcxpU5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_GuDTrERa_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GuDTrERa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6EWVFkYv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_NHsxrqmq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Etr9ztc1, 1, m, &cVar_Etr9ztc1_sendMessage);
}

void Heavy_WSTD_EQ::cVar_Etr9ztc1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6pPEGBjO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_7KP4nH80_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tTkVrg58, HV_BINOP_MULTIPLY, 1, m, &cBinop_tTkVrg58_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_oPcXFBRE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_7KP4nH80_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_4YEDNchz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_wyMfIoMM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_wyMfIoMM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mKFxwIUB, HV_BINOP_MULTIPLY, 1, m, &cBinop_mKFxwIUB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_24pgS7Mw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QImocv3f, HV_BINOP_MULTIPLY, 1, m, &cBinop_QImocv3f_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_C5WAAX3u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_24pgS7Mw_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_oePHRlEP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TiUsaE5I, HV_BINOP_MULTIPLY, 1, m, &cBinop_TiUsaE5I_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_tS7mm3Sl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_pbyOzmCu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_pbyOzmCu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WtVKkEKe, HV_BINOP_MULTIPLY, 1, m, &cBinop_WtVKkEKe_sendMessage);
}

void Heavy_WSTD_EQ::cVar_sndpX6Yz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7ZOnAFUf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_FofYVaOd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R6JcjVTB_sendMessage);
}

void Heavy_WSTD_EQ::cVar_uAE7C6Fr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_aZqcxpU5_sendMessage);
}

void Heavy_WSTD_EQ::cCast_mD2JVxHj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_a8jSCmOK_sendMessage);
}

void Heavy_WSTD_EQ::cCast_trJvEsis_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_0UWejf8w_sendMessage);
}

void Heavy_WSTD_EQ::cSend_veGt0r2J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ExMN53im_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_EtNt8FRd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_saORuQgj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_m2Kpm2Jw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WzqSYTei_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_6EWVFkYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ZcMa2Wex_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ZcMa2Wex_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k4ReZjqn, HV_BINOP_MULTIPLY, 1, m, &cBinop_k4ReZjqn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_k4ReZjqn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_0Iayf5Ot_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0Iayf5Ot_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_m2Kpm2Jw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_6pPEGBjO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_grqryv5D_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_grqryv5D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QNNSif0U_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rMDt1ums_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iiQRq7R3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LdaTBBai_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TEvuR2Rs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xAQoe6bv_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tTkVrg58_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JsAuIOiH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_mKFxwIUB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JvMFECKH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_QImocv3f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_smT6lHJp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_TiUsaE5I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zV7qjYzm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_WtVKkEKe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IYfIUQvX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_uA6BCvsE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sndpX6Yz, 0, m, &cVar_sndpX6Yz_sendMessage);
}

void Heavy_WSTD_EQ::cCast_cFjES9tw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uAE7C6Fr, 1, m, &cVar_uAE7C6Fr_sendMessage);
}

void Heavy_WSTD_EQ::cCast_QNNSif0U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_xAQoe6bv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tTkVrg58, HV_BINOP_MULTIPLY, 0, m, &cBinop_tTkVrg58_sendMessage);
}

void Heavy_WSTD_EQ::cCast_iiQRq7R3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TiUsaE5I, HV_BINOP_MULTIPLY, 0, m, &cBinop_TiUsaE5I_sendMessage);
}

void Heavy_WSTD_EQ::cCast_TEvuR2Rs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mKFxwIUB, HV_BINOP_MULTIPLY, 0, m, &cBinop_mKFxwIUB_sendMessage);
}

void Heavy_WSTD_EQ::cCast_rMDt1ums_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WtVKkEKe, HV_BINOP_MULTIPLY, 0, m, &cBinop_WtVKkEKe_sendMessage);
}

void Heavy_WSTD_EQ::cCast_LdaTBBai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QImocv3f, HV_BINOP_MULTIPLY, 0, m, &cBinop_QImocv3f_sendMessage);
}

void Heavy_WSTD_EQ::cCast_R6JcjVTB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Etr9ztc1, 0, m, &cVar_Etr9ztc1_sendMessage);
}

void Heavy_WSTD_EQ::cCast_7ZOnAFUf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uAE7C6Fr, 0, m, &cVar_uAE7C6Fr_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Uia3D3wp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_loQXEiWM, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_0yQncL9U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Qdqgn4ar, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Y6Fi3MV9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kZM2G7JC, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_g50oX0MO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5zwmhCfv, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_tn7LlWZc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ViBQ4eus_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_ViBQ4eus_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LHOxfEFP, HV_BINOP_DIVIDE, 1, m, &cBinop_LHOxfEFP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Wo2lHIYE_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_xXVjFwsh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_fbf8f8Mo_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_fRibboYg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_xXVjFwsh_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_fbf8f8Mo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LHOxfEFP, HV_BINOP_DIVIDE, 0, m, &cBinop_LHOxfEFP_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Wo2lHIYE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fRibboYg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_LHOxfEFP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hoGZLwJT, HV_BINOP_MULTIPLY, 1, m, &cBinop_hoGZLwJT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hoGZLwJT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pA42FjI8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vx5Ts6oT_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_K3eFtBqr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4ZPpz63d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_ONiuj33d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_bCGnMlaX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_I5Ub78a2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_vQqLvMyw_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_vQqLvMyw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hoGZLwJT, HV_BINOP_MULTIPLY, 0, m, &cBinop_hoGZLwJT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_1h2xOZBP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_EzJSdJ7u_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_EzJSdJ7u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dR96SJCD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_hddOQ4sW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c18SR6lV, HV_BINOP_MULTIPLY, 1, m, &cBinop_c18SR6lV_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3fKC2DVE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_H4qCP6qD, 1, m, &cVar_H4qCP6qD_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_rvzbACU8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gSUN65Gt, HV_BINOP_MULTIPLY, 1, m, &cBinop_gSUN65Gt_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_kIp8kRkK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_EsIioy1L_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_EsIioy1L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DMEGv7Cb, HV_BINOP_MULTIPLY, 1, m, &cBinop_DMEGv7Cb_sendMessage);
}

void Heavy_WSTD_EQ::cVar_H4qCP6qD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mkQ4d6Fh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_VA6DWIcg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BjknLcWT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_I5Ub78a2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XfSKAw5h_sendMessage);
}

void Heavy_WSTD_EQ::cVar_qGfiWmgp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_1h2xOZBP_sendMessage);
}

void Heavy_WSTD_EQ::cCast_pA42FjI8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_K3eFtBqr_sendMessage);
}

void Heavy_WSTD_EQ::cCast_vx5Ts6oT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_ONiuj33d_sendMessage);
}

void Heavy_WSTD_EQ::cSend_4ZPpz63d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tUQ1rc2b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_bCGnMlaX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xL2N5fsn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_8PDHqALj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YwqTO3jA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_dR96SJCD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_x782ROeC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_x782ROeC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L6tXZcur, HV_BINOP_MULTIPLY, 1, m, &cBinop_L6tXZcur_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_L6tXZcur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_UrlgIWqA_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_UrlgIWqA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8PDHqALj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_mkQ4d6Fh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_rRArDXWL_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_rRArDXWL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_78oyU2EK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wul3NOQM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8lXybQ3F_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tBnU6tjL_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RMoRkUkk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Uia3D3wp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_c18SR6lV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0yQncL9U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_gSUN65Gt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Y6Fi3MV9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_DMEGv7Cb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g50oX0MO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_LtQG7m4o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qGfiWmgp, 1, m, &cVar_qGfiWmgp_sendMessage);
}

void Heavy_WSTD_EQ::cCast_5NDPNukr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VA6DWIcg, 0, m, &cVar_VA6DWIcg_sendMessage);
}

void Heavy_WSTD_EQ::cCast_BjknLcWT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qGfiWmgp, 0, m, &cVar_qGfiWmgp_sendMessage);
}

void Heavy_WSTD_EQ::cCast_XfSKAw5h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_H4qCP6qD, 0, m, &cVar_H4qCP6qD_sendMessage);
}

void Heavy_WSTD_EQ::cCast_8lXybQ3F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c18SR6lV, HV_BINOP_MULTIPLY, 0, m, &cBinop_c18SR6lV_sendMessage);
}

void Heavy_WSTD_EQ::cCast_wul3NOQM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gSUN65Gt, HV_BINOP_MULTIPLY, 0, m, &cBinop_gSUN65Gt_sendMessage);
}

void Heavy_WSTD_EQ::cCast_tBnU6tjL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RMoRkUkk, HV_BINOP_MULTIPLY, 0, m, &cBinop_RMoRkUkk_sendMessage);
}

void Heavy_WSTD_EQ::cCast_78oyU2EK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DMEGv7Cb, HV_BINOP_MULTIPLY, 0, m, &cBinop_DMEGv7Cb_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_t0kiN6UB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6LGvib9v, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_fP7Ilear_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zRLmUq2K, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_O0l9a98Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WSbsCUON, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_AJ5hCT99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_enhfAWwg, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_xl3AMcsQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_el8lwS8B, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_wYoBTsvu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JRvvHIUf_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_JRvvHIUf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_btRz3NgB, HV_BINOP_DIVIDE, 1, m, &cBinop_btRz3NgB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zysiR2sU_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_lzGhQjpp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_VxGygozb_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_ibotljCX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_lzGhQjpp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_VxGygozb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_btRz3NgB, HV_BINOP_DIVIDE, 0, m, &cBinop_btRz3NgB_sendMessage);
}

void Heavy_WSTD_EQ::cCast_zysiR2sU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ibotljCX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_btRz3NgB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dLtAwTY6, HV_BINOP_MULTIPLY, 1, m, &cBinop_dLtAwTY6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_dLtAwTY6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DYSoDQ8N_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iZajMxnr_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_t9jeNwyr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_RMtEsEe2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_Vw4W44dF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hwBhEMlC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Z2NAN0J3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_qmeo5LEw_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qmeo5LEw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dLtAwTY6, HV_BINOP_MULTIPLY, 0, m, &cBinop_dLtAwTY6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mGhltVot_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_47l5QmBM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_47l5QmBM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q3QWJHgT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_bnDTqSR3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qnISxSJr, HV_BINOP_MULTIPLY, 1, m, &cBinop_qnISxSJr_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_4ruDzE5B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_lq1cFXHO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_lq1cFXHO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_bnDTqSR3_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_7hHgMPui_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_PrbBvHKq_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_PrbBvHKq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_M5GnOFDt, HV_BINOP_MULTIPLY, 1, m, &cBinop_M5GnOFDt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LXNgk7Lo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c3lZfRga, HV_BINOP_MULTIPLY, 1, m, &cBinop_c3lZfRga_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_bHHpv8of_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_buZx13s7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_buZx13s7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_LXNgk7Lo_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_cp3ch0hy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oI40K8id, 1, m, &cVar_oI40K8id_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_4giZU9Lb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Kt6c9XPB, HV_BINOP_MULTIPLY, 1, m, &cBinop_Kt6c9XPB_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_wPxd6kJm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ebWnAZzF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ebWnAZzF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fZfa1IJ4, HV_BINOP_MULTIPLY, 1, m, &cBinop_fZfa1IJ4_sendMessage);
}

void Heavy_WSTD_EQ::cVar_oI40K8id_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Qa1dUJR6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_bxGcZ5eG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GRTaiZqZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_Z2NAN0J3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u0EKAGCS_sendMessage);
}

void Heavy_WSTD_EQ::cVar_U1xSrIyV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_mGhltVot_sendMessage);
}

void Heavy_WSTD_EQ::cCast_iZajMxnr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_Vw4W44dF_sendMessage);
}

void Heavy_WSTD_EQ::cCast_DYSoDQ8N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_t9jeNwyr_sendMessage);
}

void Heavy_WSTD_EQ::cSend_RMtEsEe2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3qb4Kx2a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_hwBhEMlC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2Hie5wTs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_UrjaGvOC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cbpoVODA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_q3QWJHgT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_cdtpHojx_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_cdtpHojx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0KY8jgmL, HV_BINOP_MULTIPLY, 1, m, &cBinop_0KY8jgmL_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0KY8jgmL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_SVcJKGvB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_SVcJKGvB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UrjaGvOC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_Qa1dUJR6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ldcidYcs_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ldcidYcs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_b1QG498F_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bRzBaXCe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jIdVC6Sv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_K0amgQIr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cmPCXhwp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NTIpRRR5_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qnISxSJr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_t0kiN6UB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_M5GnOFDt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fP7Ilear_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_c3lZfRga_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O0l9a98Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Kt6c9XPB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AJ5hCT99_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_fZfa1IJ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xl3AMcsQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_UN5Lbtdd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_U1xSrIyV, 1, m, &cVar_U1xSrIyV_sendMessage);
}

void Heavy_WSTD_EQ::cCast_GMg0qc30_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bxGcZ5eG, 0, m, &cVar_bxGcZ5eG_sendMessage);
}

void Heavy_WSTD_EQ::cCast_K0amgQIr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c3lZfRga, HV_BINOP_MULTIPLY, 0, m, &cBinop_c3lZfRga_sendMessage);
}

void Heavy_WSTD_EQ::cCast_b1QG498F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_NTIpRRR5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qnISxSJr, HV_BINOP_MULTIPLY, 0, m, &cBinop_qnISxSJr_sendMessage);
}

void Heavy_WSTD_EQ::cCast_jIdVC6Sv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Kt6c9XPB, HV_BINOP_MULTIPLY, 0, m, &cBinop_Kt6c9XPB_sendMessage);
}

void Heavy_WSTD_EQ::cCast_cmPCXhwp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_M5GnOFDt, HV_BINOP_MULTIPLY, 0, m, &cBinop_M5GnOFDt_sendMessage);
}

void Heavy_WSTD_EQ::cCast_bRzBaXCe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fZfa1IJ4, HV_BINOP_MULTIPLY, 0, m, &cBinop_fZfa1IJ4_sendMessage);
}

void Heavy_WSTD_EQ::cCast_GRTaiZqZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_U1xSrIyV, 0, m, &cVar_U1xSrIyV_sendMessage);
}

void Heavy_WSTD_EQ::cCast_u0EKAGCS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oI40K8id, 0, m, &cVar_oI40K8id_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qmo8nfBs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_X9HLxwtO, 1, m, &cIf_X9HLxwtO_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_3bv6VFn3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_tCvV2yKI, m);
}

void Heavy_WSTD_EQ::cBinop_UXY1qJiX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3bv6VFn3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_tnHUArsm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_X9HLxwtO, 0, m, &cIf_X9HLxwtO_sendMessage);
}

void Heavy_WSTD_EQ::cSwitchcase_NQIjN1Qn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_LOr7DI0O, 0, m, &cSlice_LOr7DI0O_sendMessage);
      break;
    }
    default: {
      cSwitchcase_omto0u4X_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_LOr7DI0O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_GSHOjuke_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_GSHOjuke_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_olVBsYjG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GSHOjuke_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_GSHOjuke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_H2rjlE9G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_3vZv4RXg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_vW6wIHf7_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_WlSJt7Ok, 0, m, &cIf_WlSJt7Ok_sendMessage);
}

void Heavy_WSTD_EQ::cIf_WlSJt7Ok_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_6fBfdNcT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_4kGS3SvJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_vRx13sWz_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_m9fOYZuq_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_NVjeTrn2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_PzCgHfN1, HV_BINOP_POW, 0, m, &cBinop_PzCgHfN1_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_PzCgHfN1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K6MVspJg, 0, m, &cIf_K6MVspJg_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Lpb6Nt97_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_207eY8rA_sendMessage);
}

void Heavy_WSTD_EQ::cCast_eb4XsL7L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4kGS3SvJ, 0, m, &cIf_4kGS3SvJ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_UUzUEEz9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_vrybsTrk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_vrybsTrk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4kGS3SvJ, 1, m, &cIf_4kGS3SvJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_m9fOYZuq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_Lpb6Nt97_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_vRx13sWz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_K6MVspJg, 0, m, &cIf_K6MVspJg_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_207eY8rA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PzCgHfN1, HV_BINOP_POW, 1, m, &cBinop_PzCgHfN1_sendMessage);
  cMsg_NVjeTrn2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_K6MVspJg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_cZt0SmLv, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_vW6wIHf7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WlSJt7Ok, 1, m, &cIf_WlSJt7Ok_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6fBfdNcT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OvO2YEhE, HV_BINOP_GREATER_THAN, 1, m, &cBinop_OvO2YEhE_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_tMt4yrBi, HV_BINOP_EQ, 1, m, &cBinop_tMt4yrBi_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_G7FI0isn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Xapv3Pw3, HV_BINOP_ADD, 0, m, &cBinop_Xapv3Pw3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Xapv3Pw3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UUzUEEz9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eb4XsL7L_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_OvO2YEhE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K6MVspJg, 1, m, &cIf_K6MVspJg_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tMt4yrBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QbgikhKU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_QbgikhKU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_cZt0SmLv, m);
}

void Heavy_WSTD_EQ::cCast_My0XpHE7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Xapv3Pw3, HV_BINOP_ADD, 1, m, &cBinop_Xapv3Pw3_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_OvO2YEhE, HV_BINOP_GREATER_THAN, 0, m, &cBinop_OvO2YEhE_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_tMt4yrBi, HV_BINOP_EQ, 0, m, &cBinop_tMt4yrBi_sendMessage);
}

void Heavy_WSTD_EQ::cCast_4soRQIno_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3vZv4RXg, 0, m, &cVar_3vZv4RXg_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Rcb224zI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_G7FI0isn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_Yjf10teR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_JBiTSApS_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_rM34nlFH, 0, m, &cIf_rM34nlFH_sendMessage);
}

void Heavy_WSTD_EQ::cIf_rM34nlFH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ALFJTcJ7_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_EUKN0ASx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_QjIQEoek_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_2hucyxUf_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_VPLNjddt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_SCBpgihF, HV_BINOP_POW, 0, m, &cBinop_SCBpgihF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_SCBpgihF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_h5JocpeT, 0, m, &cIf_h5JocpeT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_fZQMsGOU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_i0l3cYfY_sendMessage);
}

void Heavy_WSTD_EQ::cCast_0fSo0gwW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EUKN0ASx, 0, m, &cIf_EUKN0ASx_sendMessage);
}

void Heavy_WSTD_EQ::cCast_2fyVEHWU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_0rMEGDaW_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0rMEGDaW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EUKN0ASx, 1, m, &cIf_EUKN0ASx_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_2hucyxUf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_fZQMsGOU_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_QjIQEoek_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_h5JocpeT, 0, m, &cIf_h5JocpeT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_i0l3cYfY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SCBpgihF, HV_BINOP_POW, 1, m, &cBinop_SCBpgihF_sendMessage);
  cMsg_VPLNjddt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_h5JocpeT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_xIzDKH8t_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TnAnUcOL_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_r7MHAw8E_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_JBiTSApS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rM34nlFH, 1, m, &cIf_rM34nlFH_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ALFJTcJ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QIQv37G3, HV_BINOP_GREATER_THAN, 1, m, &cBinop_QIQv37G3_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_tI7W5lEy, HV_BINOP_EQ, 1, m, &cBinop_tI7W5lEy_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_cxjQvnCh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5IkrntZ0, HV_BINOP_ADD, 0, m, &cBinop_5IkrntZ0_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5IkrntZ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2fyVEHWU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0fSo0gwW_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_QIQv37G3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_h5JocpeT, 1, m, &cIf_h5JocpeT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tI7W5lEy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m4cZyDrx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_m4cZyDrx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_xIzDKH8t_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TnAnUcOL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_r7MHAw8E_sendMessage);
}

void Heavy_WSTD_EQ::cCast_8QWtfsQh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Yjf10teR, 0, m, &cVar_Yjf10teR_sendMessage);
}

void Heavy_WSTD_EQ::cCast_yrPDHaln_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cxjQvnCh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_gPKxQgYC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5IkrntZ0, HV_BINOP_ADD, 1, m, &cBinop_5IkrntZ0_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_QIQv37G3, HV_BINOP_GREATER_THAN, 0, m, &cBinop_QIQv37G3_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_tI7W5lEy, HV_BINOP_EQ, 0, m, &cBinop_tI7W5lEy_sendMessage);
}

void Heavy_WSTD_EQ::cVar_n4ojyqON_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_aeNR7jfV_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_ZNg2eCSO, 0, m, &cIf_ZNg2eCSO_sendMessage);
}

void Heavy_WSTD_EQ::cIf_ZNg2eCSO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_lLHavm3v_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_ohIFxiX0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_shwah1nx_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_hYiwNjET_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_7yM0jYkr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UTr0sKsQ, HV_BINOP_POW, 0, m, &cBinop_UTr0sKsQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_UTr0sKsQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VRdsZXIV, 0, m, &cIf_VRdsZXIV_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_saZPwiJa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_IdO1UjVW_sendMessage);
}

void Heavy_WSTD_EQ::cCast_VJqVoSOO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ohIFxiX0, 0, m, &cIf_ohIFxiX0_sendMessage);
}

void Heavy_WSTD_EQ::cCast_9EAVxXVR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_LP8zPAec_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LP8zPAec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ohIFxiX0, 1, m, &cIf_ohIFxiX0_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hYiwNjET_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_saZPwiJa_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_shwah1nx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_VRdsZXIV, 0, m, &cIf_VRdsZXIV_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_IdO1UjVW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UTr0sKsQ, HV_BINOP_POW, 1, m, &cBinop_UTr0sKsQ_sendMessage);
  cMsg_7yM0jYkr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_VRdsZXIV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_oUQAyoNz, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_aeNR7jfV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZNg2eCSO, 1, m, &cIf_ZNg2eCSO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_lLHavm3v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_owkZ8RKr, HV_BINOP_GREATER_THAN, 1, m, &cBinop_owkZ8RKr_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_W6IEKgsZ, HV_BINOP_EQ, 1, m, &cBinop_W6IEKgsZ_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_hvtcfwW8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Q6HCFPGG, HV_BINOP_ADD, 0, m, &cBinop_Q6HCFPGG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Q6HCFPGG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9EAVxXVR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VJqVoSOO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_owkZ8RKr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VRdsZXIV, 1, m, &cIf_VRdsZXIV_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_W6IEKgsZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ci1X74um_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_Ci1X74um_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_oUQAyoNz, m);
}

void Heavy_WSTD_EQ::cCast_Vs9Orssc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Q6HCFPGG, HV_BINOP_ADD, 1, m, &cBinop_Q6HCFPGG_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_owkZ8RKr, HV_BINOP_GREATER_THAN, 0, m, &cBinop_owkZ8RKr_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_W6IEKgsZ, HV_BINOP_EQ, 0, m, &cBinop_W6IEKgsZ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_KsZcsVuW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_n4ojyqON, 0, m, &cVar_n4ojyqON_sendMessage);
}

void Heavy_WSTD_EQ::cCast_4dJqGDj5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hvtcfwW8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_CKqHPvfS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_Sxoc2svG, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cSwitchcase_r2I7iVas_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_buVuCxZJ, 0, m, &cSlice_buVuCxZJ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_vKJtvid4_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_buVuCxZJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_7AeBVpCf_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_7AeBVpCf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_pVpvRVYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7AeBVpCf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_7AeBVpCf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_E5oEripj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_vKJtvid4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_P0npav1p, 0, m, &cSlice_P0npav1p_sendMessage);
      break;
    }
    default: {
      cSwitchcase_NQIjN1Qn_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_P0npav1p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ZOkarfg8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ZOkarfg8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_C45RFSwe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZOkarfg8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_ZOkarfg8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2OPTDclH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_omto0u4X_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_AfAQipbg, 0, m, &cSlice_AfAQipbg_sendMessage);
      break;
    }
    default: {
      cSwitchcase_icxRvT7U_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_AfAQipbg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_jpYOY6bK_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_jpYOY6bK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_a8vJajib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jpYOY6bK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_jpYOY6bK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Vy20iz7r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_icxRvT7U_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_pCVIddNe, 0, m, &cSlice_pCVIddNe_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_pCVIddNe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_UNDpmJIJ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_UNDpmJIJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_iGz0WdY8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UNDpmJIJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_UNDpmJIJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_khiU34i9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_KPYo2o40_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_c97ERpN2, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_IIgIY0hz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7DrQF2lV, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_TxTl48t9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iReI7s7L, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_yHOZri9k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bUVaFKUL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_YjPhDkaD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1fm1vt77, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_jSlWhgog_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_KNQfQlI6_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_KNQfQlI6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tBifUyNR, HV_BINOP_DIVIDE, 1, m, &cBinop_tBifUyNR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BOB7kNVz_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_ipJjhZIX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_OV2bdx2R_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_8PWjY56l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_ipJjhZIX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_OV2bdx2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tBifUyNR, HV_BINOP_DIVIDE, 0, m, &cBinop_tBifUyNR_sendMessage);
}

void Heavy_WSTD_EQ::cCast_BOB7kNVz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8PWjY56l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_tBifUyNR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4oTXTYPV, HV_BINOP_MULTIPLY, 1, m, &cBinop_4oTXTYPV_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_4oTXTYPV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZaxZyiB2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H7WezDjA_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_Ud3vNXd0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vas2qKkD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_7GwOPRFy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_elNdpvUP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Rh22khWu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_5RjiFLDq_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5RjiFLDq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4oTXTYPV, HV_BINOP_MULTIPLY, 0, m, &cBinop_4oTXTYPV_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_eSCK4rwX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_Hj0u52fw_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Hj0u52fw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bfw9K0Ch_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_K9IGaSjS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dlpdhWeF, 1, m, &cVar_dlpdhWeF_sendMessage);
}

void Heavy_WSTD_EQ::cVar_dlpdhWeF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YA4EgejO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_MRTocDBd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_21q5XHtC, HV_BINOP_MULTIPLY, 1, m, &cBinop_21q5XHtC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_V4k7sQQQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_MRTocDBd_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_DvFyCuLO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_rxOqpSIF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_rxOqpSIF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gzlB88GM, HV_BINOP_MULTIPLY, 1, m, &cBinop_gzlB88GM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_cHF7E3ma_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GHWNkNeD, HV_BINOP_MULTIPLY, 1, m, &cBinop_GHWNkNeD_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_1Dx4vSHv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_cHF7E3ma_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hyHxDgF5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Hby0q2sB, HV_BINOP_MULTIPLY, 1, m, &cBinop_Hby0q2sB_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_DjND9fPE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_mmj3Ui9B_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mmj3Ui9B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HrNhbkqc, HV_BINOP_MULTIPLY, 1, m, &cBinop_HrNhbkqc_sendMessage);
}

void Heavy_WSTD_EQ::cVar_2lzLIP3v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zRYahIc3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_Rh22khWu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lD3NU9jK_sendMessage);
}

void Heavy_WSTD_EQ::cVar_WuB0r1Mt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_eSCK4rwX_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ZaxZyiB2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_Ud3vNXd0_sendMessage);
}

void Heavy_WSTD_EQ::cCast_H7WezDjA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_7GwOPRFy_sendMessage);
}

void Heavy_WSTD_EQ::cSend_vas2qKkD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_d2UvV6BS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_elNdpvUP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_c4GZNigF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_byIV4DAq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zeVVvZjU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_bfw9K0Ch_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_D9ixAgIN_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_D9ixAgIN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QIM5gfnR, HV_BINOP_MULTIPLY, 1, m, &cBinop_QIM5gfnR_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_QIM5gfnR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_h52knXsQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_h52knXsQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_byIV4DAq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_YA4EgejO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_cKERWFfY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_cKERWFfY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LFxvOIXX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fthypEHW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uct9JqzZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jtamWOwK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6ZMdULNM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jiDTy1JK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_21q5XHtC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KPYo2o40_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_gzlB88GM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IIgIY0hz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_GHWNkNeD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TxTl48t9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Hby0q2sB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yHOZri9k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_HrNhbkqc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YjPhDkaD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_yA6ahYGw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2lzLIP3v, 0, m, &cVar_2lzLIP3v_sendMessage);
}

void Heavy_WSTD_EQ::cCast_rOmxmg0R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WuB0r1Mt, 1, m, &cVar_WuB0r1Mt_sendMessage);
}

void Heavy_WSTD_EQ::cCast_jtamWOwK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GHWNkNeD, HV_BINOP_MULTIPLY, 0, m, &cBinop_GHWNkNeD_sendMessage);
}

void Heavy_WSTD_EQ::cCast_LFxvOIXX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_jiDTy1JK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_21q5XHtC, HV_BINOP_MULTIPLY, 0, m, &cBinop_21q5XHtC_sendMessage);
}

void Heavy_WSTD_EQ::cCast_uct9JqzZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Hby0q2sB, HV_BINOP_MULTIPLY, 0, m, &cBinop_Hby0q2sB_sendMessage);
}

void Heavy_WSTD_EQ::cCast_6ZMdULNM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gzlB88GM, HV_BINOP_MULTIPLY, 0, m, &cBinop_gzlB88GM_sendMessage);
}

void Heavy_WSTD_EQ::cCast_fthypEHW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HrNhbkqc, HV_BINOP_MULTIPLY, 0, m, &cBinop_HrNhbkqc_sendMessage);
}

void Heavy_WSTD_EQ::cCast_lD3NU9jK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dlpdhWeF, 0, m, &cVar_dlpdhWeF_sendMessage);
}

void Heavy_WSTD_EQ::cCast_zRYahIc3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WuB0r1Mt, 0, m, &cVar_WuB0r1Mt_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_va1UkjJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iymgOlvP, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_LCjbkZlY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XonqUsLJ, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_mlEC15vS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4ymlGirf, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_JvbDCZSL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IpMCiPw6, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_h7krDc4r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_QOxmLgX0_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_QOxmLgX0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SRtSqwLl, HV_BINOP_DIVIDE, 1, m, &cBinop_SRtSqwLl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5IC6LSSO_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_Xu9mLYQE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_FVyVJ81q_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_ytDD6NXm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_Xu9mLYQE_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_FVyVJ81q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SRtSqwLl, HV_BINOP_DIVIDE, 0, m, &cBinop_SRtSqwLl_sendMessage);
}

void Heavy_WSTD_EQ::cCast_5IC6LSSO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ytDD6NXm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_SRtSqwLl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KhAEwudB, HV_BINOP_MULTIPLY, 1, m, &cBinop_KhAEwudB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_KhAEwudB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EbaWmpPr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_t7yKTE22_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_9wetsXuM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Mu3q8cSl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_5ZW5b4xg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_d69XwBLI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_wEbPrUMO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_xqbgl8rE_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_xqbgl8rE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KhAEwudB, HV_BINOP_MULTIPLY, 0, m, &cBinop_KhAEwudB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_DwGVwgcO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_Ot0BTfmU_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Ot0BTfmU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VIJsR0Yu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_y4vmAPbX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Rk1ZscFC, HV_BINOP_MULTIPLY, 1, m, &cBinop_Rk1ZscFC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_vNBNYJJ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xVbqMyZF, 1, m, &cVar_xVbqMyZF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_vekwnLFO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zUblXaac, HV_BINOP_MULTIPLY, 1, m, &cBinop_zUblXaac_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_81CWA5m8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Ww60YMro_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Ww60YMro_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CdlY4iy9, HV_BINOP_MULTIPLY, 1, m, &cBinop_CdlY4iy9_sendMessage);
}

void Heavy_WSTD_EQ::cVar_xVbqMyZF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aCfHDoya_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_ninmu3NU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cXAAoSTP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_wEbPrUMO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0A2ZHEZ5_sendMessage);
}

void Heavy_WSTD_EQ::cVar_YS68iqXR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_DwGVwgcO_sendMessage);
}

void Heavy_WSTD_EQ::cCast_t7yKTE22_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_5ZW5b4xg_sendMessage);
}

void Heavy_WSTD_EQ::cCast_EbaWmpPr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_9wetsXuM_sendMessage);
}

void Heavy_WSTD_EQ::cSend_Mu3q8cSl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SykvRUNN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_d69XwBLI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5prTbPmS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_XqmGBk5N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_clU5SGcK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_VIJsR0Yu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_46bKDRTF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_46bKDRTF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4ySTZT8k, HV_BINOP_MULTIPLY, 1, m, &cBinop_4ySTZT8k_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_4ySTZT8k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_GGc0Xstv_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GGc0Xstv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XqmGBk5N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_aCfHDoya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_KmaUwtdL_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_KmaUwtdL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_s564u2Zg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_apqXAgnc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pMauJyPK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RGhgygUF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_iCRXdiEB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_va1UkjJo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Rk1ZscFC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LCjbkZlY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_zUblXaac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mlEC15vS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_CdlY4iy9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JvbDCZSL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_LX5uPseo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YS68iqXR, 1, m, &cVar_YS68iqXR_sendMessage);
}

void Heavy_WSTD_EQ::cCast_i0B0hxWf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ninmu3NU, 0, m, &cVar_ninmu3NU_sendMessage);
}

void Heavy_WSTD_EQ::cCast_cXAAoSTP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YS68iqXR, 0, m, &cVar_YS68iqXR_sendMessage);
}

void Heavy_WSTD_EQ::cCast_0A2ZHEZ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xVbqMyZF, 0, m, &cVar_xVbqMyZF_sendMessage);
}

void Heavy_WSTD_EQ::cCast_pMauJyPK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Rk1ZscFC, HV_BINOP_MULTIPLY, 0, m, &cBinop_Rk1ZscFC_sendMessage);
}

void Heavy_WSTD_EQ::cCast_apqXAgnc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zUblXaac, HV_BINOP_MULTIPLY, 0, m, &cBinop_zUblXaac_sendMessage);
}

void Heavy_WSTD_EQ::cCast_RGhgygUF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iCRXdiEB, HV_BINOP_MULTIPLY, 0, m, &cBinop_iCRXdiEB_sendMessage);
}

void Heavy_WSTD_EQ::cCast_s564u2Zg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CdlY4iy9, HV_BINOP_MULTIPLY, 0, m, &cBinop_CdlY4iy9_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_1AL7nvZH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WiZk9A0c, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_OrRlWf3A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_czc3zBQG, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_ItxSpo7k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_b3Z1VMFH, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_FSSY3Yoj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zi8ojdYw, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_1uiLN3em_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TzQ3WEaf, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_qOqFuOIB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_2qe6p8cS_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_2qe6p8cS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JP36DU8M, HV_BINOP_DIVIDE, 1, m, &cBinop_JP36DU8M_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_f4t9ukl9_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_qaGIARkx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_s64zHejG_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_LjUvqG1L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_qaGIARkx_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_s64zHejG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JP36DU8M, HV_BINOP_DIVIDE, 0, m, &cBinop_JP36DU8M_sendMessage);
}

void Heavy_WSTD_EQ::cCast_f4t9ukl9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LjUvqG1L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_JP36DU8M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_svbL6fwW, HV_BINOP_MULTIPLY, 1, m, &cBinop_svbL6fwW_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_svbL6fwW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1bXnosy1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lT4Z1ic0_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_FzhO1QLE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_c9DVCWBr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_t0ewQshR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zZL3apSV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_JQSoaq6h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_Ycp2otYP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Ycp2otYP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_svbL6fwW, HV_BINOP_MULTIPLY, 0, m, &cBinop_svbL6fwW_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Jri7N1oB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_kE17gspi_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_kE17gspi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hxZCU5BX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_LAli5tcU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vxiQSwVE, HV_BINOP_MULTIPLY, 1, m, &cBinop_vxiQSwVE_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_4sAAHNop_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_XTvf8HvO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_XTvf8HvO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_LAli5tcU_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_FCp1AKfV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_hVgle8tJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hVgle8tJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jBctoR2q, HV_BINOP_MULTIPLY, 1, m, &cBinop_jBctoR2q_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_b78LIpTZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5sCdzeZt, HV_BINOP_MULTIPLY, 1, m, &cBinop_5sCdzeZt_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_PKRUBNVN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Lc73anCZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Lc73anCZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_b78LIpTZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qTtQeWOA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bk2lVakQ, 1, m, &cVar_bk2lVakQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_JtjRDv8q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kKwVml8v, HV_BINOP_MULTIPLY, 1, m, &cBinop_kKwVml8v_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_fRYGDayY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_t398xvQe_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_t398xvQe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_G139okac, HV_BINOP_MULTIPLY, 1, m, &cBinop_G139okac_sendMessage);
}

void Heavy_WSTD_EQ::cVar_bk2lVakQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uY69o6pG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_UGmlENyg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_x29UgsKk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_JQSoaq6h_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oIuwxSr0_sendMessage);
}

void Heavy_WSTD_EQ::cVar_PFL04SSZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_Jri7N1oB_sendMessage);
}

void Heavy_WSTD_EQ::cCast_lT4Z1ic0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_t0ewQshR_sendMessage);
}

void Heavy_WSTD_EQ::cCast_1bXnosy1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_FzhO1QLE_sendMessage);
}

void Heavy_WSTD_EQ::cSend_c9DVCWBr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZMYum3sS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_zZL3apSV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Tgnb9b1W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_rj28TXSC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QhEvDkji_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_hxZCU5BX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_1U8ILPzG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_1U8ILPzG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3NOK8RMa, HV_BINOP_MULTIPLY, 1, m, &cBinop_3NOK8RMa_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3NOK8RMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_xtyt6wWH_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_xtyt6wWH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rj28TXSC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_uY69o6pG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_tmuswCLu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tmuswCLu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GxuafV6D_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9CgesaCt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PaoJ5fbY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_D5aEwixC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZCwQg9db_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BltUp9qb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_vxiQSwVE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1AL7nvZH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_jBctoR2q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OrRlWf3A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_5sCdzeZt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ItxSpo7k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_kKwVml8v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FSSY3Yoj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_G139okac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1uiLN3em_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_TBbGuElg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UGmlENyg, 0, m, &cVar_UGmlENyg_sendMessage);
}

void Heavy_WSTD_EQ::cCast_OcIK99rX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PFL04SSZ, 1, m, &cVar_PFL04SSZ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_D5aEwixC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5sCdzeZt, HV_BINOP_MULTIPLY, 0, m, &cBinop_5sCdzeZt_sendMessage);
}

void Heavy_WSTD_EQ::cCast_GxuafV6D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_BltUp9qb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vxiQSwVE, HV_BINOP_MULTIPLY, 0, m, &cBinop_vxiQSwVE_sendMessage);
}

void Heavy_WSTD_EQ::cCast_PaoJ5fbY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kKwVml8v, HV_BINOP_MULTIPLY, 0, m, &cBinop_kKwVml8v_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ZCwQg9db_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jBctoR2q, HV_BINOP_MULTIPLY, 0, m, &cBinop_jBctoR2q_sendMessage);
}

void Heavy_WSTD_EQ::cCast_9CgesaCt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_G139okac, HV_BINOP_MULTIPLY, 0, m, &cBinop_G139okac_sendMessage);
}

void Heavy_WSTD_EQ::cCast_oIuwxSr0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bk2lVakQ, 0, m, &cVar_bk2lVakQ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_x29UgsKk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PFL04SSZ, 0, m, &cVar_PFL04SSZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_xIzDKH8t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CKqHPvfS, 1, m, &cIf_CKqHPvfS_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_2hARdPHZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Sxoc2svG, m);
}

void Heavy_WSTD_EQ::cBinop_TnAnUcOL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2hARdPHZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_r7MHAw8E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CKqHPvfS, 0, m, &cIf_CKqHPvfS_sendMessage);
}

void Heavy_WSTD_EQ::cVar_quPlospt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0rwVoS6S, HV_BINOP_DIVIDE, 0, m, &cBinop_0rwVoS6S_sendMessage);
}

void Heavy_WSTD_EQ::cVar_gyK8kFJS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pPSWJLm0, HV_BINOP_DIVIDE, 1, m, &cBinop_pPSWJLm0_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_0rwVoS6S, HV_BINOP_DIVIDE, 1, m, &cBinop_0rwVoS6S_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_dbadTfuw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pdQ5b87n, HV_BINOP_DIVIDE, 0, m, &cBinop_pdQ5b87n_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_h3upvB0i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pdQ5b87n, HV_BINOP_DIVIDE, 1, m, &cBinop_pdQ5b87n_sendMessage);
}

void Heavy_WSTD_EQ::cCast_1Qb6Pari_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pPSWJLm0, HV_BINOP_DIVIDE, 0, m, &cBinop_pPSWJLm0_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ca6Zs0MX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_quPlospt, 0, m, &cVar_quPlospt_sendMessage);
}

void Heavy_WSTD_EQ::cCast_jgTcddYF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gyK8kFJS, 0, m, &cVar_gyK8kFJS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_pPSWJLm0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_dbadTfuw_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0rwVoS6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_h3upvB0i_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_pdQ5b87n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_Fta4hiF1_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_TBBYuYEp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_Xg0CJwwG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Wp5lYIjO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_D70WcnSD_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Fta4hiF1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Wp5lYIjO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_D70WcnSD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_TBBYuYEp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Xg0CJwwG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_La8zi46f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_kXEu0NQy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_5Ca47154_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_r2I7iVas_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_UekhutNI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_5Ca47154_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_r2I7iVas_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_CtDoQzxl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_5Ca47154_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_r2I7iVas_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_fMGLJ56o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_5Ca47154_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_r2I7iVas_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_La8zi46f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_5Ca47154_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_r2I7iVas_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_dB716uLK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_taQaVfAa, 0, m, &cVar_taQaVfAa_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_ugDGTzbm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_iv4AX7qc, 0, m, &cVar_iv4AX7qc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WU8vmRnZ, 0, m, &cVar_WU8vmRnZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_n45wO3vz, 0, m, &cVar_n45wO3vz_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_v3MZaTXS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iv4AX7qc, 0, m, &cVar_iv4AX7qc_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_cXNEaHwj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WU8vmRnZ, 0, m, &cVar_WU8vmRnZ_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_2bFBofJt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_n45wO3vz, 0, m, &cVar_n45wO3vz_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_UnnJFRAt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VA6DWIcg, 0, m, &cVar_VA6DWIcg_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_eCOWL2cF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LtQG7m4o_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5NDPNukr_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_7SRaH4BO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1VYbb7y3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QA6uEy0U_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_htA62vWS_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_pEkYyncY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fZdznzat_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LShsrbM3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_T739TdeX_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_k0s7Gj3M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7Ixepinq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RCFIPeWG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bPRrlIBF_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_6OIwRzw4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8KeEAQAf_sendMessage(_c, 0, m);
  cMsg_tn7LlWZc_sendMessage(_c, 0, m);
  cMsg_wYoBTsvu_sendMessage(_c, 0, m);
  cMsg_jSlWhgog_sendMessage(_c, 0, m);
  cMsg_h7krDc4r_sendMessage(_c, 0, m);
  cMsg_qOqFuOIB_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_sndpX6Yz, 0, m, &cVar_sndpX6Yz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_VA6DWIcg, 0, m, &cVar_VA6DWIcg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_bxGcZ5eG, 0, m, &cVar_bxGcZ5eG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2lzLIP3v, 0, m, &cVar_2lzLIP3v_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ninmu3NU, 0, m, &cVar_ninmu3NU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_UGmlENyg, 0, m, &cVar_UGmlENyg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_BOgL15rd, 0, m, &cVar_BOgL15rd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FifCE51N, 0, m, &cVar_FifCE51N_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8WEI3JvX, 0, m, &cVar_8WEI3JvX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WzzHaa7x, 0, m, &cVar_WzzHaa7x_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZaR7pMZW, 0, m, &cVar_ZaR7pMZW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_20fD9Ygb, 0, m, &cVar_20fD9Ygb_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5x8BCa1G, 0, m, &cVar_5x8BCa1G_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_UvzccisB, 0, m, &cVar_UvzccisB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_olVBsYjG, 0, m, &cVar_olVBsYjG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3vZv4RXg, 0, m, &cVar_3vZv4RXg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Yjf10teR, 0, m, &cVar_Yjf10teR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_n4ojyqON, 0, m, &cVar_n4ojyqON_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_pVpvRVYt, 0, m, &cVar_pVpvRVYt_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_C45RFSwe, 0, m, &cVar_C45RFSwe_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_a8vJajib, 0, m, &cVar_a8vJajib_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_iGz0WdY8, 0, m, &cVar_iGz0WdY8_sendMessage);
  cMsg_ugDGTzbm_sendMessage(_c, 0, m);
  cMsg_dB716uLK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_ExMN53im_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k4ReZjqn, HV_BINOP_MULTIPLY, 0, m, &cBinop_k4ReZjqn_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_saORuQgj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_oPcXFBRE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_4YEDNchz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_C5WAAX3u_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_oePHRlEP_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_WzqSYTei_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_NHsxrqmq_sendMessage);
  cMsg_tS7mm3Sl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_tUQ1rc2b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L6tXZcur, HV_BINOP_MULTIPLY, 0, m, &cBinop_L6tXZcur_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_xL2N5fsn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_rvzbACU8_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_YwqTO3jA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RMoRkUkk, HV_BINOP_MULTIPLY, 1, m, &cBinop_RMoRkUkk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_hddOQ4sW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_3fKC2DVE_sendMessage);
  cMsg_kIp8kRkK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_3qb4Kx2a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0KY8jgmL, HV_BINOP_MULTIPLY, 0, m, &cBinop_0KY8jgmL_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_2Hie5wTs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4ruDzE5B_sendMessage(_c, 0, m);
  cMsg_7hHgMPui_sendMessage(_c, 0, m);
  cMsg_bHHpv8of_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_4giZU9Lb_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_cbpoVODA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_cp3ch0hy_sendMessage);
  cMsg_wPxd6kJm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_H2rjlE9G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ninmu3NU, 0, m, &cVar_ninmu3NU_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_khiU34i9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LX5uPseo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_i0B0hxWf_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_E5oEripj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4soRQIno_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_My0XpHE7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Rcb224zI_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_Vy20iz7r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KsZcsVuW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Vs9Orssc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4dJqGDj5_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_2OPTDclH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8QWtfsQh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gPKxQgYC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yrPDHaln_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_d2UvV6BS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QIM5gfnR, HV_BINOP_MULTIPLY, 0, m, &cBinop_QIM5gfnR_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_c4GZNigF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_V4k7sQQQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_DvFyCuLO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_1Dx4vSHv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_hyHxDgF5_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_zeVVvZjU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_K9IGaSjS_sendMessage);
  cMsg_DjND9fPE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_SykvRUNN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4ySTZT8k, HV_BINOP_MULTIPLY, 0, m, &cBinop_4ySTZT8k_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_5prTbPmS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_vekwnLFO_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_clU5SGcK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iCRXdiEB, HV_BINOP_MULTIPLY, 1, m, &cBinop_iCRXdiEB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_y4vmAPbX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_vNBNYJJ6_sendMessage);
  cMsg_81CWA5m8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_ZMYum3sS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3NOK8RMa, HV_BINOP_MULTIPLY, 0, m, &cBinop_3NOK8RMa_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_Tgnb9b1W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4sAAHNop_sendMessage(_c, 0, m);
  cMsg_FCp1AKfV_sendMessage(_c, 0, m);
  cMsg_PKRUBNVN_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_JtjRDv8q_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_QhEvDkji_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_qTtQeWOA_sendMessage);
  cMsg_fRYGDayY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_zbn5mGLA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_taQaVfAa, 0, m, &cVar_taQaVfAa_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_EQ::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_varread_f(&sVarf_3WJBcLGs, VOf(Bf0));
    __hv_varread_f(&sVarf_QsjKsq2r, VOf(Bf1));
    __hv_varread_f(&sVarf_aqVQWq1E, VOf(Bf2));
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf0), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_CiFi0U0D, VOf(Bf0));
    __hv_varread_f(&sVarf_9pYvl3dk, VOf(Bf1));
    __hv_varread_f(&sVarf_qZ8h6tW9, VOf(Bf3));
    __hv_add_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf0), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_kZZ5h6If, VOf(Bf0));
    __hv_line_f(&sLine_WhspttYG, VOf(Bf1));
    __hv_line_f(&sLine_n3JASBrD, VOf(Bf4));
    __hv_line_f(&sLine_d90Xsgzl, VOf(Bf5));
    __hv_line_f(&sLine_wdJwMooU, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_DZ9OPUA5, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf4), VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_1a2jUahA, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_loQXEiWM, VOf(Bf6));
    __hv_zero_f(VOf(Bf4));
    __hv_line_f(&sLine_Qdqgn4ar, VOf(Bf1));
    __hv_line_f(&sLine_kZM2G7JC, VOf(Bf0));
    __hv_line_f(&sLine_5zwmhCfv, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_RzLQim5G, VIf(I0), VIf(Bf6), VIf(Bf4), VIf(Bf1), VIf(Bf0), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_tCvV2yKI, VOf(Bf0));
    __hv_mul_f(VIf(Bf7), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_6LGvib9v, VOf(Bf7));
    __hv_line_f(&sLine_zRLmUq2K, VOf(Bf1));
    __hv_line_f(&sLine_WSbsCUON, VOf(Bf4));
    __hv_line_f(&sLine_enhfAWwg, VOf(Bf6));
    __hv_line_f(&sLine_el8lwS8B, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_Nal4f1Fy, VIf(I0), VIf(Bf7), VIf(Bf1), VIf(Bf4), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_HnMuUfpx, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_3WJBcLGs, VIf(Bf5));
    __hv_varwrite_f(&sVarf_QsjKsq2r, VIf(Bf0));
    __hv_varwrite_f(&sVarf_aqVQWq1E, VIf(Bf6));
    __hv_line_f(&sLine_c97ERpN2, VOf(Bf6));
    __hv_line_f(&sLine_7DrQF2lV, VOf(Bf0));
    __hv_line_f(&sLine_iReI7s7L, VOf(Bf5));
    __hv_line_f(&sLine_bUVaFKUL, VOf(Bf8));
    __hv_line_f(&sLine_1fm1vt77, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_niZUSZ1t, VIf(I1), VIf(Bf6), VIf(Bf0), VIf(Bf5), VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_cZt0SmLv, VOf(Bf8));
    __hv_mul_f(VIf(Bf4), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_iymgOlvP, VOf(Bf4));
    __hv_zero_f(VOf(Bf5));
    __hv_line_f(&sLine_XonqUsLJ, VOf(Bf0));
    __hv_line_f(&sLine_4ymlGirf, VOf(Bf6));
    __hv_line_f(&sLine_IpMCiPw6, VOf(Bf1));
    __hv_biquad_f(&sBiquad_s_fymrXeR2, VIf(I1), VIf(Bf4), VIf(Bf5), VIf(Bf0), VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_Sxoc2svG, VOf(Bf6));
    __hv_mul_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_WiZk9A0c, VOf(Bf1));
    __hv_line_f(&sLine_czc3zBQG, VOf(Bf0));
    __hv_line_f(&sLine_b3Z1VMFH, VOf(Bf5));
    __hv_line_f(&sLine_zi8ojdYw, VOf(Bf4));
    __hv_line_f(&sLine_TzQ3WEaf, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_qQWlHVMB, VIf(I1), VIf(Bf1), VIf(Bf0), VIf(Bf5), VIf(Bf4), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_oUQAyoNz, VOf(Bf4));
    __hv_mul_f(VIf(Bf7), VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_CiFi0U0D, VIf(Bf8));
    __hv_varwrite_f(&sVarf_9pYvl3dk, VIf(Bf6));
    __hv_varwrite_f(&sVarf_qZ8h6tW9, VIf(Bf4));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf3), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_EQ::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_EQ::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
